@@ -3,32 +3,35 @@
 #
 # Gammapy documentation build configuration file.
 
-import os
 import datetime
+import os
+
+# Get configuration information from setup.cfg
+from configparser import ConfigParser
+
 from pkg_resources import get_distribution
 
-# Load all of the global Astropy configuration
+# Load all the global Astropy configuration
 from sphinx_astropy.conf import *
 
-# Load utils docs functions
-from gammapy.utils.docs import gammapy_sphinx_ext_activate
-
 # Sphinx-gallery config
 from sphinx_gallery.sorting import FileNameSortKey
 
-# Get configuration information from setup.cfg
-from configparser import ConfigParser
+# Load utils docs functions
+from gammapy.utils.docs import gammapy_sphinx_ext_activate
 
 conf = ConfigParser()
 conf.read([os.path.join(os.path.dirname(__file__), "..", "setup.cfg")])
 setup_cfg = dict(conf.items("metadata"))
 
+# -- General configuration ----------------------------------------------------
+
+# Matplotlib directive sets whether to show a link to the source in HTML
 plot_html_show_source_link = False
 
+# If true, figures, tables and code-blocks are automatically numbered if they have a caption
 numfig = False
 
-# -- General configuration ----------------------------------------------------
-
 # If your documentation needs a minimal Sphinx version, state it here.
 # needs_sphinx = '1.1'
 
@@ -56,9 +59,10 @@ intersphinx_mapping["pandas"] = ("https://pandas.pydata.org/pandas-docs/stable/"
 exclude_patterns.append("_templates")
 exclude_patterns.append("_static")
 exclude_patterns.append("**.ipynb_checkpoints")
+exclude_patterns.append("modeling/gallery/*/*.ipynb")
+exclude_patterns.append("modeling/gallery/*/*.md5")
+exclude_patterns.append("modeling/gallery/*/*.py")
 
-#
-# -- nbsphinx settings
 extensions.extend(
     [
         "nbsphinx",
@@ -67,10 +71,13 @@ extensions.extend(
         "sphinx.ext.mathjax",
         "sphinx_gallery.gen_gallery",
         "sphinx.ext.doctest",
+        "sphinx_panels",
+        "sphinx_copybutton",
     ]
 )
 nbsphinx_execute = "never"
-
+copybutton_prompt_text = r">>> |\.\.\. |\$ |In \[\d*\]: | {2,5}\.\.\.: | {5,8}: "
+copybutton_prompt_is_regexp = True
 # --
 
 # This is added to the end of RST files - a good place to put substitutions to
@@ -87,34 +94,19 @@ copyright = "{}, {}".format(datetime.datetime.now().year, setup_cfg["author"])
 
 version = get_distribution(project).version
 release = version
+switch_version = version
+if len(version) > 5:
+    switch_version = "dev"
 
 # -- Options for HTML output ---------------------------------------------------
 
 # A NOTE ON HTML THEMES
 # The global astropy configuration uses a custom theme, 'bootstrap-astropy',
 # which is installed along with astropy. A different theme can be used or
-# the options for this theme can be modified by overriding some of the
+# the options for this theme can be modified by overriding some
 # variables set in the global configuration. The variables set in the
 # global configuration are listed below, commented out.
 
-# html_theme_options = {
-#    'logotext1': 'gamma',  # white,  semi-bold
-#    'logotext2': 'py',  # orange, light
-#    'logotext3': ':docs'  # white,  light
-# }
-
-html_theme_options = {
-    "canonical_url": setup_cfg["url_docs"],
-    "analytics_id": "",
-    "logo_only": False,
-    "display_version": True,
-    "prev_next_buttons_location": "bottom",
-    # Toc options
-    "collapse_navigation": False,
-    "sticky_navigation": True,
-    "navigation_depth": 3,
-}
-
 # Add any paths that contain custom themes here, relative to this directory.
 # To use a different custom theme, add the directory containing the theme.
 # html_theme_path = []
@@ -122,18 +114,22 @@ html_theme_options = {
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes. To override the custom theme, set this to the
 # name of a builtin theme or the name of a custom theme in html_theme_path.
-html_theme = "sphinx_rtd_theme"
+html_theme = "pydata_sphinx_theme"
 
-# Custom sidebar templates, maps document names to template names.
-# html_sidebars = {}
+# Static files to copy after template files
+html_static_path = ["_static"]
 
 # The name of an image file (within the static path) to use as favicon of the
 # docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
 # pixels large.
-# html_favicon = ''
+html_logo = os.path.join(html_static_path[0], "gammapy_logo_nav.png")
+html_favicon = os.path.join(html_static_path[0], "gammapy_logo.ico")
 
-# TODO: set this image also in the title bar
-# (html_logo is not the right option)
+# Custom sidebar templates, maps document names to template names.
+html_sidebars = {
+    "search": "search-field.html",
+    "navigation": "sidebar-nav-bs.html",
+}
 
 # If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
 # using the given strftime format.
@@ -144,42 +140,58 @@ html_theme = "sphinx_rtd_theme"
 html_title = "{} v{}".format(project, release)
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = project + "doc"
-
-# Static files to copy after template files
-html_static_path = ["_static"]
-
-gammapy_sphinx_ext_activate()
+htmlhelp_basename = f"{project}doc"
 
+html_theme_options = {
+    # toc options
+    "collapse_navigation": False,
+    "navigation_depth": 2,
+    "show_prev_next": False,
+    # links in menu
+    "icon_links": [
+        {
+            "name": "Github",
+            "url": "https://github.com/gammapy/gammapy",
+            "icon": "fab fa-github-square",
+        },
+        {
+            "name": "Twitter",
+            "url": "https://twitter.com/gammapyST",
+            "icon": "fab fa-twitter-square",
+        },
+        {
+            "name": "Slack",
+            "url": "https://gammapy.slack.com/",
+            "icon": "fab fa-slack",
+        },
+    ],
+    "switcher": {
+        "json_url": "https://docs.gammapy.org/stable/switcher.json",
+        "version_match": switch_version,
+    },
+    "navbar_end": ["version-switcher", "navbar-icon-links"],
+}
 
 # Theme style
 # html_style = ''
-def setup(app):
-    app.add_css_file("gammapy.css")
-    app.add_js_file("copybutton.js")
-    app.add_js_file("gammapy.js")
+html_css_files = ["gammapy.css"]
 
-
-# copybutton.js provides hide/show button for python prompts >>>
-# slightly modified to work on RTD theme from javascript file in easydev package
-# https://github.com/cokelaer/easydev/blob/master/easydev/share/copybutton.js
-
-
-html_favicon = os.path.join(html_static_path[0], "gammapy_logo.ico")
+gammapy_sphinx_ext_activate()
 
 # -- Options for LaTeX output --------------------------------------------------
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass [howto/manual]).
 latex_documents = [
-    ("index", project + ".tex", project + " Documentation", author, "manual")
+    ("index", f"{project}.tex", f"{project} Documentation", author, "manual")
 ]
 
 # -- Options for manual page output --------------------------------------------
 
 # One entry per manual page. List of tuples
 # (source start file, name, description, authors, manual section).
-man_pages = [("index", project.lower(), project + " Documentation", [author], 1)]
+man_pages = [("index", project.lower(), f"{project} Documentation", [author], 1)]
+
 
 # -- Other options --
 
