@@ -14,11 +14,26 @@ By default, the Generalized Gaussian is defined as :
 the normalization is expressed as:
 
 .. math::
-    N = \frac{1}{ 2 \pi \sqrt(1-e^2) r_{\rm eff}^2 \eta \Gamma(2\eta)}\,
+    N = \frac{1}{ 2 \pi \sqrt(1-e^2) r_{0}^2 \eta \Gamma(2\eta)}\,
 
 where :math:`\Gamma` is the gamma function.
 This analytical norm is approximated so it may not integrate to unity in extreme cases
 if ellipticity tend to one and radius is large or :math:`\eta` much larger than one (outside the default range).
+
+The effective radius is given by: 
+
+.. math::
+    \r_{rm eff}(\text{lon}, \text{lat}) = \sqrt{
+        (r_M \sin(\Delta \phi))^2 +
+        (r_m \cos(\Delta \phi))^2
+    }.
+
+where :math:`r_M` (:math:`r_m`) is the major (minor) semiaxis, and
+:math:`\Delta \phi` is the difference between `phi`, the position angle of the model, and the
+position angle of the evaluation point.
+If the eccentricity (:math:`e`) is null it reduces to :math:`r_0`.
+
+
 """
 
 # %%
