@@ -4,10 +4,10 @@ import abc
 import warnings
 import numpy as np
 import astropy.units as u
-from astropy.table import Column, Table
-from astropy.time import Time
+from astropy.table import Table
 from astropy.wcs import FITSFixedWarning
-from gammapy.estimators import FluxPoints, LightCurve
+from gammapy.estimators import FluxPoints
+from gammapy.maps import MapAxis, Maps, RegionGeom
 from gammapy.modeling.models import (
     DiskSpatialModel,
     GaussianSpatialModel,
@@ -19,17 +19,17 @@ from gammapy.modeling.models import (
 from gammapy.utils.gauss import Gauss2DPDF
 from gammapy.utils.scripts import make_path
 from gammapy.utils.table import table_standardise_units_inplace
-from .core import SourceCatalog, SourceCatalogObject
+from .core import SourceCatalog, SourceCatalogObject, format_flux_points_table
 
 __all__ = [
-    "SourceCatalogObject4FGL",
-    "SourceCatalogObject3FGL",
-    "SourceCatalogObject2FHL",
-    "SourceCatalogObject3FHL",
-    "SourceCatalog4FGL",
-    "SourceCatalog3FGL",
     "SourceCatalog2FHL",
+    "SourceCatalog3FGL",
     "SourceCatalog3FHL",
+    "SourceCatalog4FGL",
+    "SourceCatalogObject2FHL",
+    "SourceCatalogObject3FGL",
+    "SourceCatalogObject3FHL",
+    "SourceCatalogObject4FGL",
 ]
 
 
@@ -45,6 +45,12 @@ class SourceCatalogObjectFermiBase(SourceCatalogObject, abc.ABC):
     """Base class for Fermi-LAT catalogs."""
 
     asso = ["ASSOC1", "ASSOC2", "ASSOC_TEV", "ASSOC_GAM1", "ASSOC_GAM2", "ASSOC_GAM3"]
+    flux_points_meta = {
+        "sed_type_init": "flux",
+        "n_sigma": 1,
+        "sqrt_ts_threshold_ul": 1,
+        "n_sigma_ul": 2,
+    }
 
     def __str__(self):
         return self.info()
@@ -87,7 +93,7 @@ class SourceCatalogObjectFermiBase(SourceCatalogObject, abc.ABC):
             ss += "{:<20s} : {}\n".format("Extended name", d["Extended_Source_Name"])
 
         def get_nonentry_keys(keys):
-            vals = [d[_].strip() for _ in keys]
+            vals = [str(d[_]).strip() for _ in keys]
             return ", ".join([_ for _ in vals if _ != ""])
 
         associations = get_nonentry_keys(keys)
@@ -149,7 +155,9 @@ class SourceCatalogObjectFermiBase(SourceCatalogObject, abc.ABC):
 
     def _info_spectral_points(self):
         ss = "\n*** Spectral points ***\n\n"
-        lines = self.flux_points.table_formatted.pformat(max_width=-1, max_lines=-1)
+        lines = format_flux_points_table(self.flux_points_table).pformat(
+            max_width=-1, max_lines=-1
+        )
         ss += "\n".join(lines)
         return ss
 
@@ -184,17 +192,30 @@ class SourceCatalogObjectFermiBase(SourceCatalogObject, abc.ABC):
         lat_err = semi_major / scale_1sigma
         lon_err = semi_minor / scale_1sigma / np.cos(d["DEJ2000"])
 
-        if model.tag != "TemplateSpatialModel":
+        if "TemplateSpatialModel" not in model.tag:
             model.parameters["lon_0"].error = lon_err
             model.parameters["lat_0"].error = lat_err
             model.phi_0 = phi_0
 
-    def sky_model(self):
+    def sky_model(self, name=None):
         """Sky model (`~gammapy.modeling.models.SkyModel`)."""
+        if name is None:
+            name = self.name
+
         return SkyModel(
             spatial_model=self.spatial_model(),
             spectral_model=self.spectral_model(),
-            name=self.name,
+            name=name,
+        )
+
+    @property
+    def flux_points(self):
+        """Flux points (`~gammapy.estimators.FluxPoints`)."""
+
+        return FluxPoints.from_table(
+            table=self.flux_points_table,
+            reference_model=self.sky_model(),
+            format="gadf-sed",
         )
 
 
@@ -214,7 +235,6 @@ class SourceCatalogObject4FGL(SourceCatalogObjectFermiBase):
         "ASSOC_GAM2",
         "ASSOC_GAM3",
     ]
-    _ebounds = u.Quantity([50, 100, 300, 1000, 3000, 10000, 30000, 300000], "MeV")
 
     def _info_more(self):
         d = self.data
@@ -246,11 +266,16 @@ class SourceCatalogObject4FGL(SourceCatalogObjectFermiBase):
 
         elif spec_type == "PLSuperExpCutoff":
             tag = "PLEC"
-            fmt = "{:<45s} : {} +- {}\n"
-            ss += fmt.format(
-                "Exponential factor", d["PLEC_Expfactor"], d["Unc_PLEC_Expfactor"]
-            )
-            ss += "{:<45s} : {} +- {}\n".format(
+            fmt = "{:<45s} : {:.4f} +- {:.4f}\n"
+            if "PLEC_ExpfactorS" in d:
+                ss += fmt.format(
+                    "Exponential factor", d["PLEC_ExpfactorS"], d["Unc_PLEC_ExpfactorS"]
+                )
+            else:
+                ss += fmt.format(
+                    "Exponential factor", d["PLEC_Expfactor"], d["Unc_PLEC_Expfactor"]
+                )
+            ss += "{:<45s} : {:.4f} +- {:.4f}\n".format(
                 "Super-exponential cutoff index",
                 d["PLEC_Exp_Index"],
                 d["Unc_PLEC_Exp_Index"],
@@ -394,24 +419,36 @@ class SourceCatalogObject4FGL(SourceCatalogObjectFermiBase):
                 "beta": self.data["Unc_LP_beta"],
             }
         elif spec_type == "PLSuperExpCutoff":
-            tag = "SuperExpCutoffPowerLaw4FGLSpectralModel"
+            if "PLEC_ExpfactorS" in self.data:
+                tag = "SuperExpCutoffPowerLaw4FGLDR3SpectralModel"
+                expfactor = self.data["PLEC_ExpfactorS"]
+                expfactor_err = self.data["Unc_PLEC_ExpfactorS"]
+                index_1 = self.data["PLEC_IndexS"]
+                index_1_err = self.data["Unc_PLEC_IndexS"]
+            else:
+                tag = "SuperExpCutoffPowerLaw4FGLSpectralModel"
+                expfactor = self.data["PLEC_Expfactor"]
+                expfactor_err = self.data["Unc_PLEC_Expfactor"]
+                index_1 = self.data["PLEC_Index"]
+                index_1_err = self.data["Unc_PLEC_Index"]
+
             pars = {
                 "reference": self.data["Pivot_Energy"],
                 "amplitude": self.data["PLEC_Flux_Density"],
-                "index_1": self.data["PLEC_Index"],
+                "index_1": index_1,
                 "index_2": self.data["PLEC_Exp_Index"],
-                "expfactor": self.data["PLEC_Expfactor"],
+                "expfactor": expfactor,
             }
             errs = {
                 "amplitude": self.data["Unc_PLEC_Flux_Density"],
-                "index_1": self.data["Unc_PLEC_Index"],
-                "index_2": np.nan_to_num(self.data["Unc_PLEC_Exp_Index"]),
-                "expfactor": self.data["Unc_PLEC_Expfactor"],
+                "index_1": index_1_err,
+                "index_2": np.nan_to_num(float(self.data["Unc_PLEC_Exp_Index"])),
+                "expfactor": expfactor_err,
             }
         else:
             raise ValueError(f"Invalid spec_type: {spec_type!r}")
 
-        model = Model.create(tag, **pars)
+        model = Model.create(tag, "spectral", **pars)
 
         for name, value in errs.items():
             model.parameters[name].error = value
@@ -419,13 +456,13 @@ class SourceCatalogObject4FGL(SourceCatalogObjectFermiBase):
         return model
 
     @property
-    def flux_points(self):
-        """Flux points (`~gammapy.spectrum.FluxPoints`)."""
+    def flux_points_table(self):
+        """Flux points (`~astropy.table.Table`)."""
         table = Table()
-        table.meta["SED_TYPE"] = "flux"
+        table.meta.update(self.flux_points_meta)
 
-        table["e_min"] = self._ebounds[:-1]
-        table["e_max"] = self._ebounds[1:]
+        table["e_min"] = self.data["fp_energy_edges"][:-1]
+        table["e_max"] = self.data["fp_energy_edges"][1:]
 
         flux = self._get_flux_values("Flux_Band")
         flux_err = self._get_flux_values("Unc_Flux_Band")
@@ -452,48 +489,63 @@ class SourceCatalogObject4FGL(SourceCatalogObjectFermiBase):
         table["e2dnde_ul"][is_ul] = e2dnde_ul[is_ul]
 
         # Square root of test statistic
-        table["sqrt_TS"] = self.data["Sqrt_TS_Band"]
-        return FluxPoints(table)
+        table["sqrt_ts"] = self.data["Sqrt_TS_Band"]
+        return table
 
     def _get_flux_values(self, prefix, unit="cm-2 s-1"):
         values = self.data[prefix]
         return u.Quantity(values, unit)
 
-    @property
-    def lightcurve(self):
-        """Lightcurve (`~gammapy.time.LightCurve`)."""
-        flux = self.data["Flux_History"]
+    def lightcurve(self, interval="1-year"):
+        """Lightcurve (`~gammapy.estimators.FluxPoints`).
 
-        # Flux error is given as asymmetric high/low
-        flux_errn = -self.data["Unc_Flux_History"][:, 0]
-        flux_errp = self.data["Unc_Flux_History"][:, 1]
+        Parameters
+        ----------
+        interval : {'1-year', '2-month'}
+            Time interval of the lightcurve. Default is '1-year'.
+            Note that '2-month' is not available for all catalogue version.
+        """
 
-        # Really the time binning is stored in a separate HDU in the FITS
-        # catalog file called `Hist_Start`, with a single column `Hist_Start`
-        # giving the time binning in MET (mission elapsed time)
-        # This is not available here for now.
-        # TODO: read that info in `SourceCatalog3FGL` and pass it down to the
-        # `SourceCatalogObject3FGL` object somehow.
+        if interval == "1-year":
+            tag = "Flux_History"
+            if tag not in self.data or "time_axis" not in self.data:
+                raise ValueError(
+                    "'1-year' interval is not available for this catalogue version"
+                )
+            time_axis = self.data["time_axis"]
+            tag_sqrt_ts = "Sqrt_TS_History"
 
-        # For now, we just hard-code the start and stop time and assume
-        # equally-spaced time intervals. This is roughly correct,
-        # for plotting the difference doesn't matter, only for analysis
-        time_start = Time("2008-08-04T15:43:36.0000")
-        time_end = Time("2016-08-02T05:44:11.9999")
-        n_points = len(flux)
-        time_step = (time_end - time_start) / n_points
-        time_bounds = time_start + np.arange(n_points + 1) * time_step
+        elif interval == "2-month":
+            tag = "Flux2_History"
+            if tag not in self.data or "time_axis_2" not in self.data:
+                raise ValueError(
+                    "2-month interval is not available for this catalogue version"
+                )
+            time_axis = self.data["time_axis_2"]
+            tag_sqrt_ts = "Sqrt_TS2_History"
+        else:
+            raise ValueError("Time intervals available are '1-year' or '2-month'")
 
-        table = Table(
-            [
-                Column(time_bounds[:-1].utc.mjd, "time_min"),
-                Column(time_bounds[1:].utc.mjd, "time_max"),
-                Column(flux, "flux"),
-                Column(flux_errp, "flux_errp"),
-                Column(flux_errn, "flux_errn"),
-            ]
+        energy_axis = MapAxis.from_energy_edges([50, 300000] * u.MeV)
+        geom = RegionGeom.create(region=self.position, axes=[energy_axis, time_axis])
+
+        names = ["flux", "flux_errp", "flux_errn", "flux_ul", "ts"]
+        maps = Maps.from_geom(geom=geom, names=names)
+
+        maps["flux"].quantity = self.data[tag]
+        maps["flux_errp"].quantity = self.data[f"Unc_{tag}"][:, 1]
+        maps["flux_errn"].quantity = -self.data[f"Unc_{tag}"][:, 0]
+        maps["flux_ul"].quantity = compute_flux_points_ul(
+            maps["flux"].quantity, maps["flux_errp"].quantity
+        )
+        maps["ts"].quantity = self.data[tag_sqrt_ts] ** 2
+
+        return FluxPoints.from_maps(
+            maps=maps,
+            sed_type="flux",
+            reference_model=self.sky_model(),
+            meta=self.flux_points.meta.copy(),
         )
-        return LightCurve(table)
 
 
 class SourceCatalogObject3FGL(SourceCatalogObjectFermiBase):
@@ -502,8 +554,14 @@ class SourceCatalogObject3FGL(SourceCatalogObjectFermiBase):
     Catalog is represented by `~gammapy.catalog.SourceCatalog3FGL`.
     """
 
-    _ebounds = u.Quantity([100, 300, 1000, 3000, 10000, 100000], "MeV")
-    _ebounds_suffix = ["100_300", "300_1000", "1000_3000", "3000_10000", "10000_100000"]
+    _energy_edges = u.Quantity([100, 300, 1000, 3000, 10000, 100000], "MeV")
+    _energy_edges_suffix = [
+        "100_300",
+        "300_1000",
+        "1000_3000",
+        "3000_10000",
+        "10000_100000",
+    ]
     energy_range = u.Quantity([100, 100000], "MeV")
     """Energy range used for the catalog.
 
@@ -676,7 +734,7 @@ class SourceCatalogObject3FGL(SourceCatalogObjectFermiBase):
         else:
             raise ValueError(f"Invalid spec_type: {spec_type!r}")
 
-        model = Model.create(tag, **pars)
+        model = Model.create(tag, "spectral", **pars)
 
         for name, value in errs.items():
             model.parameters[name].error = value
@@ -718,13 +776,13 @@ class SourceCatalogObject3FGL(SourceCatalogObjectFermiBase):
         return model
 
     @property
-    def flux_points(self):
-        """Flux points (`~gammapy.spectrum.FluxPoints`)."""
+    def flux_points_table(self):
+        """Flux points (`~astropy.table.Table`)."""
         table = Table()
-        table.meta["SED_TYPE"] = "flux"
+        table.meta.update(self.flux_points_meta)
 
-        table["e_min"] = self._ebounds[:-1]
-        table["e_max"] = self._ebounds[1:]
+        table["e_min"] = self._energy_edges[:-1]
+        table["e_max"] = self._energy_edges[1:]
 
         flux = self._get_flux_values("Flux")
         flux_err = self._get_flux_values("Unc_Flux")
@@ -751,48 +809,39 @@ class SourceCatalogObject3FGL(SourceCatalogObjectFermiBase):
         table["e2dnde_ul"][is_ul] = e2dnde_ul[is_ul]
 
         # Square root of test statistic
-        table["sqrt_TS"] = [self.data["Sqrt_TS" + _] for _ in self._ebounds_suffix]
-        return FluxPoints(table)
+        table["sqrt_ts"] = [self.data["Sqrt_TS" + _] for _ in self._energy_edges_suffix]
+        return table
 
     def _get_flux_values(self, prefix, unit="cm-2 s-1"):
-        values = [self.data[prefix + _] for _ in self._ebounds_suffix]
+        values = [self.data[prefix + _] for _ in self._energy_edges_suffix]
         return u.Quantity(values, unit)
 
-    @property
     def lightcurve(self):
-        """Lightcurve (`~gammapy.time.LightCurve`)."""
-        flux = self.data["Flux_History"]
+        """Lightcurve (`~gammapy.estimators.FluxPoints`)."""
+        time_axis = self.data["time_axis"]
+        tag = "Flux_History"
 
-        # Flux error is given as asymmetric high/low
-        flux_errn = -self.data["Unc_Flux_History"][:, 0]
-        flux_errp = self.data["Unc_Flux_History"][:, 1]
+        energy_axis = MapAxis.from_energy_edges(self.energy_range)
+        geom = RegionGeom.create(region=self.position, axes=[energy_axis, time_axis])
 
-        # Really the time binning is stored in a separate HDU in the FITS
-        # catalog file called `Hist_Start`, with a single column `Hist_Start`
-        # giving the time binning in MET (mission elapsed time)
-        # This is not available here for now.
-        # TODO: read that info in `SourceCatalog3FGL` and pass it down to the
-        # `SourceCatalogObject3FGL` object somehow.
+        names = ["flux", "flux_errp", "flux_errn", "flux_ul"]
+        maps = Maps.from_geom(geom=geom, names=names)
 
-        # For now, we just hard-code the start and stop time and assume
-        # equally-spaced time intervals. This is roughly correct,
-        # for plotting the difference doesn't matter, only for analysis
-        time_start = Time("2008-08-02T00:33:19")
-        time_end = Time("2012-07-31T22:45:47")
-        n_points = len(flux)
-        time_step = (time_end - time_start) / n_points
-        time_bounds = time_start + np.arange(n_points + 1) * time_step
+        maps["flux"].quantity = self.data[tag]
+        maps["flux_errp"].quantity = self.data[f"Unc_{tag}"][:, 1]
+        maps["flux_errn"].quantity = -self.data[f"Unc_{tag}"][:, 0]
+        maps["flux_ul"].quantity = compute_flux_points_ul(
+            maps["flux"].quantity, maps["flux_errp"].quantity
+        )
+        is_ul = np.isnan(maps["flux_errn"])
+        maps["flux_ul"].data[~is_ul] = np.nan
 
-        table = Table(
-            [
-                Column(time_bounds[:-1].utc.mjd, "time_min"),
-                Column(time_bounds[1:].utc.mjd, "time_max"),
-                Column(flux, "flux"),
-                Column(flux_errp, "flux_errp"),
-                Column(flux_errn, "flux_errn"),
-            ]
+        return FluxPoints.from_maps(
+            maps=maps,
+            sed_type="flux",
+            reference_model=self.sky_model(),
+            meta=self.flux_points_meta.copy(),
         )
-        return LightCurve(table)
 
 
 class SourceCatalogObject2FHL(SourceCatalogObjectFermiBase):
@@ -802,8 +851,8 @@ class SourceCatalogObject2FHL(SourceCatalogObjectFermiBase):
     """
 
     asso = ["ASSOC", "3FGL_Name", "1FHL_Name", "TeVCat_Name"]
-    _ebounds = u.Quantity([50, 171, 585, 2000], "GeV")
-    _ebounds_suffix = ["50_171", "171_585", "585_2000"]
+    _energy_edges = u.Quantity([50, 171, 585, 2000], "GeV")
+    _energy_edges_suffix = ["50_171", "171_585", "585_2000"]
     energy_range = u.Quantity([0.05, 2], "TeV")
     """Energy range used for the catalog."""
 
@@ -906,7 +955,7 @@ class SourceCatalogObject2FHL(SourceCatalogObjectFermiBase):
             "index": self.data["Unc_Spectral_Index"],
         }
 
-        model = Model.create(tag, **pars)
+        model = Model.create(tag, "spectral", **pars)
 
         for name, value in errs.items():
             model.parameters[name].error = value
@@ -914,12 +963,12 @@ class SourceCatalogObject2FHL(SourceCatalogObjectFermiBase):
         return model
 
     @property
-    def flux_points(self):
-        """Integral flux points (`~gammapy.spectrum.FluxPoints`)."""
+    def flux_points_table(self):
+        """Flux points (`~astropy.table.Table`)."""
         table = Table()
-        table.meta["SED_TYPE"] = "flux"
-        table["e_min"] = self._ebounds[:-1]
-        table["e_max"] = self._ebounds[1:]
+        table.meta.update(self.flux_points_meta)
+        table["e_min"] = self._energy_edges[:-1]
+        table["e_max"] = self._energy_edges[1:]
         table["flux"] = self._get_flux_values("Flux")
         flux_err = self._get_flux_values("Unc_Flux")
         table["flux_errn"] = np.abs(flux_err[:, 0])
@@ -931,10 +980,10 @@ class SourceCatalogObject2FHL(SourceCatalogObjectFermiBase):
         table["flux_ul"] = np.nan * flux_err.unit
         flux_ul = compute_flux_points_ul(table["flux"], table["flux_errp"])
         table["flux_ul"][is_ul] = flux_ul[is_ul]
-        return FluxPoints(table)
+        return table
 
     def _get_flux_values(self, prefix, unit="cm-2 s-1"):
-        values = [self.data[prefix + _ + "GeV"] for _ in self._ebounds_suffix]
+        values = [self.data[prefix + _ + "GeV"] for _ in self._energy_edges_suffix]
         return u.Quantity(values, unit)
 
 
@@ -948,7 +997,7 @@ class SourceCatalogObject3FHL(SourceCatalogObjectFermiBase):
     energy_range = u.Quantity([0.01, 2], "TeV")
     """Energy range used for the catalog."""
 
-    _ebounds = u.Quantity([10, 20, 50, 150, 500, 2000], "GeV")
+    _energy_edges = u.Quantity([10, 20, 50, 150, 500, 2000], "GeV")
 
     def _info_position(self):
         d = self.data
@@ -1079,7 +1128,7 @@ class SourceCatalogObject3FHL(SourceCatalogObjectFermiBase):
         else:
             raise ValueError(f"Invalid spec_type: {spec_type!r}")
 
-        model = Model.create(tag, **pars)
+        model = Model.create(tag, "spectral", **pars)
 
         for name, value in errs.items():
             model.parameters[name].error = value
@@ -1087,12 +1136,12 @@ class SourceCatalogObject3FHL(SourceCatalogObjectFermiBase):
         return model
 
     @property
-    def flux_points(self):
-        """Flux points (`~gammapy.spectrum.FluxPoints`)."""
+    def flux_points_table(self):
+        """Flux points (`~astropy.table.Table`)."""
         table = Table()
-        table.meta["SED_TYPE"] = "flux"
-        table["e_min"] = self._ebounds[:-1]
-        table["e_max"] = self._ebounds[1:]
+        table.meta.update(self.flux_points_meta)
+        table["e_min"] = self._energy_edges[:-1]
+        table["e_max"] = self._energy_edges[1:]
 
         flux = self.data["Flux_Band"]
         flux_err = self.data["Unc_Flux_Band"]
@@ -1120,7 +1169,7 @@ class SourceCatalogObject3FHL(SourceCatalogObjectFermiBase):
 
         # Square root of test statistic
         table["sqrt_ts"] = self.data["Sqrt_TS_Band"]
-        return FluxPoints(table)
+        return table
 
     def spatial_model(self):
         """Source spatial model (`~gammapy.modeling.models.SpatialModel`)."""
@@ -1197,13 +1246,18 @@ class SourceCatalog3FGL(SourceCatalog):
         )
 
         self.extended_sources_table = Table.read(filename, hdu="ExtendedSources")
+        self.hist_table = Table.read(filename, hdu="Hist_Start")
 
 
 class SourceCatalog4FGL(SourceCatalog):
     """Fermi-LAT 4FGL source catalog.
 
-    - https://arxiv.org/abs/1902.10045
-    - https://fermi.gsfc.nasa.gov/ssc/data/access/lat/8yr_catalog/
+    - https://arxiv.org/abs/1902.10045 (DR1)
+    - https://arxiv.org/abs/2005.11208 (DR2)
+    - https://arxiv.org/abs/2201.11184 (DR3)
+
+    By default we use the file of the DR3 initial release
+    from https://fermi.gsfc.nasa.gov/ssc/data/access/lat/12yr_catalog/
 
     One source is represented by `~gammapy.catalog.SourceCatalogObject4FGL`.
     """
@@ -1212,7 +1266,7 @@ class SourceCatalog4FGL(SourceCatalog):
     description = "LAT 8-year point source catalog"
     source_object_class = SourceCatalogObject4FGL
 
-    def __init__(self, filename="$GAMMAPY_DATA/catalogs/fermi/gll_psc_v20.fit.gz"):
+    def __init__(self, filename="$GAMMAPY_DATA/catalogs/fermi/gll_psc_v28.fit.gz"):
         filename = make_path(filename)
         table = Table.read(filename, hdu="LAT_Point_Source_Catalog")
         table_standardise_units_inplace(table)
@@ -1236,6 +1290,23 @@ class SourceCatalog4FGL(SourceCatalog):
         )
 
         self.extended_sources_table = Table.read(filename, hdu="ExtendedSources")
+        try:
+            self.hist_table = Table.read(filename, hdu="Hist_Start")
+            if "MJDREFI" not in self.hist_table.meta:
+                self.hist_table.meta = Table.read(filename, hdu="GTI").meta
+        except KeyError:
+            pass
+        try:
+            self.hist2_table = Table.read(filename, hdu="Hist2_Start")
+            if "MJDREFI" not in self.hist_table.meta:
+                self.hist2_table.meta = Table.read(filename, hdu="GTI").meta
+        except KeyError:
+            pass
+
+        table = Table.read(filename, hdu="EnergyBounds")
+        self.flux_points_energy_edges = np.unique(
+            np.c_[table["LowerEnergy"].quantity, table["UpperEnergy"].quantity]
+        )
 
 
 class SourceCatalog2FHL(SourceCatalog):
