@@ -3,13 +3,19 @@ import collections.abc
 import copy
 import logging
 import numpy as np
+import astropy.units as u
 from astropy.coordinates import SkyCoord
+from astropy.io import fits
 from astropy.time import Time
 from astropy.units import Quantity
-from gammapy.irf import Background3D, load_cta_irfs
-from gammapy.utils.fits import LazyFitsData, earth_location_from_dict
+from astropy.utils import lazyproperty
+import matplotlib.pyplot as plt
+from gammapy import __version__
+from gammapy.utils.fits import LazyFitsData, earth_location_to_dict
+from gammapy.utils.scripts import make_path
 from gammapy.utils.testing import Checker
-from .event_list import EventListChecker
+from gammapy.utils.time import time_ref_to_dict, time_relative_to_ref
+from .event_list import EventList, EventListChecker
 from .filters import ObservationFilter
 from .gti import GTI
 from .pointing import FixedPointingInfo
@@ -36,6 +42,9 @@ class Observation:
         Point spread function
     bkg : `~gammapy.irf.Background3D`
         Background rate model
+    rad_max: `~gammapy.irf.RadMax2D`
+        Only for point-like IRFs: RAD_MAX table (energy dependent RAD_MAX)
+        For a fixed RAD_MAX, create a RadMax2D with a single bin.
     gti : `~gammapy.data.GTI`
         Table with GTI start and stop time
     events : `~gammapy.data.EventList`
@@ -48,6 +57,7 @@ class Observation:
     edisp = LazyFitsData(cache=False)
     psf = LazyFitsData(cache=False)
     bkg = LazyFitsData(cache=False)
+    _rad_max = LazyFitsData(cache=False)
     _events = LazyFitsData(cache=False)
     _gti = LazyFitsData(cache=False)
 
@@ -60,19 +70,60 @@ class Observation:
         edisp=None,
         psf=None,
         bkg=None,
+        rad_max=None,
         events=None,
         obs_filter=None,
     ):
         self.obs_id = obs_id
-        self.obs_info = obs_info
+        self._obs_info = obs_info
         self.aeff = aeff
         self.edisp = edisp
         self.psf = psf
         self.bkg = bkg
+        self._rad_max = rad_max
         self._gti = gti
         self._events = events
         self.obs_filter = obs_filter or ObservationFilter()
 
+    @property
+    def rad_max(self):
+        # prevent circular import
+        from gammapy.irf import RadMax2D
+
+        if self._rad_max is not None:
+            return self._rad_max
+
+        # load once to avoid trigger lazy loading it three times
+        aeff = self.aeff
+        if aeff is not None and aeff.is_pointlike:
+            self._rad_max = RadMax2D.from_irf(aeff)
+            return self._rad_max
+
+        edisp = self.edisp
+        if edisp is not None and edisp.is_pointlike:
+            self._rad_max = RadMax2D.from_irf(self.edisp)
+
+        return self._rad_max
+
+    @property
+    def available_hdus(self):
+        """Which HDUs are available"""
+        available_hdus = []
+        keys = ["_events", "_gti", "aeff", "edisp", "psf", "bkg", "_rad_max"]
+        hdus = ["events", "gti", "aeff", "edisp", "psf", "bkg", "rad_max"]
+        for key, hdu in zip(keys, hdus):
+            available = self.__dict__.get(key, False)
+            available_hdu = self.__dict__.get(f"_{hdu}_hdu", False)
+            available_hdu_ = self.__dict__.get(f"_{key}_hdu", False)
+            if available or available_hdu or available_hdu_:
+                available_hdus.append(hdu)
+        return available_hdus
+
+    @property
+    def available_irfs(self):
+        """Which IRFs are available"""
+        return [_ for _ in self.available_hdus if _ not in ["events", "gti"]]
+
     @property
     def events(self):
         events = self.obs_filter.filter_events(self._events)
@@ -80,29 +131,40 @@ class Observation:
 
     @property
     def gti(self):
-        events = self.obs_filter.filter_gti(self._gti)
-        return events
+        gti = self.obs_filter.filter_gti(self._gti)
+        return gti
 
     @staticmethod
-    def _get_obs_info(pointing, deadtime_fraction):
+    def _get_obs_info(
+        pointing, deadtime_fraction, time_start, time_stop, reference_time, location
+    ):
         """Create obs info dict from in memory data"""
-        return {
+        obs_info = {
             "RA_PNT": pointing.icrs.ra.deg,
             "DEC_PNT": pointing.icrs.dec.deg,
             "DEADC": 1 - deadtime_fraction,
         }
+        obs_info.update(time_ref_to_dict(reference_time))
+        obs_info["TSTART"] = time_relative_to_ref(time_start, obs_info).to_value(u.s)
+        obs_info["TSTOP"] = time_relative_to_ref(time_stop, obs_info).to_value(u.s)
+
+        if location is not None:
+            obs_info.update(earth_location_to_dict(location))
+
+        return obs_info
 
     @classmethod
     def create(
         cls,
         pointing,
+        location=None,
         obs_id=0,
         livetime=None,
         tstart=None,
         tstop=None,
         irfs=None,
         deadtime_fraction=0.0,
-        reference_time="2000-01-01",
+        reference_time=Time("2000-01-01 00:00:00"),
     ):
         """Create an observation.
 
@@ -116,11 +178,13 @@ class Observation:
             Observation ID as identifier
         livetime : ~astropy.units.Quantity`
             Livetime exposure of the simulated observation
-        tstart : `~astropy.units.Quantity`
-            Start time of observation w.r.t reference_time
-        tstop : `~astropy.units.Quantity` w.r.t reference_time
-            Stop time of observation
-        irfs : dict
+        tstart: `~astropy.time.Time` or `~astropy.units.Quantity`
+            Start time of observation as `~astropy.time.Time` or duration
+            relative to `reference_time`
+        tstop: `astropy.time.Time` or `~astropy.units.Quantity`
+            Stop time of observation as `~astropy.time.Time` or duration
+            relative to `reference_time`
+        irfs: dict
             IRFs used for simulating the observation: `bkg`, `aeff`, `psf`, `edisp`
         deadtime_fraction : float, optional
             Deadtime fraction, defaults to 0
@@ -132,15 +196,20 @@ class Observation:
         obs : `gammapy.data.MemoryObservation`
         """
         if tstart is None:
-            tstart = Quantity(0.0, "hr")
+            tstart = reference_time.copy()
 
         if tstop is None:
             tstop = tstart + Quantity(livetime)
 
-        gti = GTI.create([tstart], [tstop], reference_time=reference_time)
+        gti = GTI.create(tstart, tstop, reference_time=reference_time)
 
         obs_info = cls._get_obs_info(
-            pointing=pointing, deadtime_fraction=deadtime_fraction
+            pointing=pointing,
+            deadtime_fraction=deadtime_fraction,
+            time_start=gti.time_start[0],
+            time_stop=gti.time_stop[0],
+            reference_time=reference_time,
+            location=location,
         )
 
         return cls(
@@ -153,58 +222,6 @@ class Observation:
             psf=irfs.get("psf"),
         )
 
-    @classmethod
-    def from_caldb(
-        cls,
-        pointing,
-        obs_id=None,
-        livetime=None,
-        tstart=None,
-        tstop=None,
-        caldb="prod2",
-        irf="South0.5hr",
-        deadtime_fraction=0.0,
-    ):
-        """Create an observation using IRFs from a given CTA CALDB.
-
-        Parameters
-        ----------
-        pointing : `~astropy.coordinates.SkyCoord`
-            Pointing position
-        obs_id : int
-            Observation ID as identifier
-        livetime : ~astropy.units.Quantity`
-            Livetime exposure of the simulated observation
-        tstart : `~astropy.units.Quantity`
-            Start time of observation
-        tstop : `~astropy.units.Quantity`
-            Stop time of observation
-        caldb : str
-            Calibration database
-        irf : str
-            Type of Instrumental response function.
-        deadtime_fraction : float, optional
-            Deadtime fraction, defaults to 0
-
-        Returns
-        -------
-        obs : `gammapy.data.Observation`
-        """
-        from .data_store import CalDBIRF
-
-        irf_loc = CalDBIRF("CTA", caldb, irf)
-        filename = irf_loc.file_dir + irf_loc.file_name
-        irfs = load_cta_irfs(filename)
-        return cls.create(
-            pointing=pointing,
-            obs_id=obs_id,
-            livetime=livetime,
-            tstart=tstart,
-            tstop=tstop,
-            irfs=irfs,
-            deadtime_fraction=deadtime_fraction,
-        )
-
     @property
     def tstart(self):
         """Observation start time (`~astropy.time.Time`)."""
@@ -252,35 +269,45 @@ class Observation:
         """
         return 1 - self.obs_info["DEADC"]
 
+    @lazyproperty
+    def obs_info(self):
+        """Observation info dictionary."""
+        meta = self._obs_info.copy() if self._obs_info is not None else {}
+        if self.events is not None:
+            meta.update(
+                {
+                    k: v
+                    for k, v in self.events.table.meta.items()
+                    if not k.startswith("HDU")
+                }
+            )
+        return meta
+
+    @lazyproperty
+    def fixed_pointing_info(self):
+        """Fixed pointing info for this observation (`FixedPointingInfo`)."""
+        return FixedPointingInfo(self.obs_info)
+
     @property
     def pointing_radec(self):
         """Pointing RA / DEC sky coordinates (`~astropy.coordinates.SkyCoord`)."""
-        lon, lat = (
-            self.obs_info.get("RA_PNT", np.nan),
-            self.obs_info.get("DEC_PNT", np.nan),
-        )
-        return SkyCoord(lon, lat, unit="deg", frame="icrs")
+        return self.fixed_pointing_info.radec
 
     @property
     def pointing_altaz(self):
-        """Pointing ALT / AZ sky coordinates (`~astropy.coordinates.SkyCoord`)."""
-        alt, az = (
-            self.obs_info.get("ALT_PNT", np.nan),
-            self.obs_info.get("AZ_PNT", np.nan),
-        )
-        return SkyCoord(az, alt, unit="deg", frame="altaz")
+        return self.fixed_pointing_info.altaz
 
     @property
     def pointing_zen(self):
         """Pointing zenith angle sky (`~astropy.units.Quantity`)."""
-        return Quantity(self.obs_info.get("ZEN_PNT", np.nan), unit="deg")
+        return self.fixed_pointing_info.altaz.zen
 
     @property
-    def fixed_pointing_info(self):
-        """Fixed pointing info for this observation (`FixedPointingInfo`)."""
-        return FixedPointingInfo(self.events.table.meta)
+    def observatory_earth_location(self):
+        """Observatory location (`~astropy.coordinates.EarthLocation`)."""
+        return self.fixed_pointing_info.location
 
-    @property
+    @lazyproperty
     def target_radec(self):
         """Target RA / DEC sky coordinates (`~astropy.coordinates.SkyCoord`)."""
         lon, lat = (
@@ -289,11 +316,6 @@ class Observation:
         )
         return SkyCoord(lon, lat, unit="deg", frame="icrs")
 
-    @property
-    def observatory_earth_location(self):
-        """Observatory location (`~astropy.coordinates.EarthLocation`)."""
-        return earth_location_from_dict(self.obs_info)
-
     @property
     def muoneff(self):
         """Observation muon efficiency."""
@@ -329,37 +351,46 @@ class Observation:
 
         Parameters
         ----------
-        figszie : tuple
+        figsize : tuple
             Figure size
         """
-        import matplotlib.pyplot as plt
+        n_irfs = len(self.available_hdus)
 
-        fig, ((ax_aeff, ax_bkg), (ax_psf, ax_edisp)) = plt.subplots(
-            nrows=2,
-            ncols=2,
+        fig, axes = plt.subplots(
+            nrows=n_irfs // 2,
+            ncols=2 + n_irfs % 2,
             figsize=figsize,
             gridspec_kw={"wspace": 0.25, "hspace": 0.25},
         )
 
-        self.aeff.plot(ax=ax_aeff)
+        axes_dict = dict(zip(self.available_hdus, axes.flatten()))
 
-        try:
-            if isinstance(self.bkg, Background3D):
-                bkg = self.bkg.to_2d()
-            else:
-                bkg = self.bkg
+        if "aeff" in self.available_hdus:
+            self.aeff.plot(ax=axes_dict["aeff"])
+            axes_dict["aeff"].set_title("Effective area")
 
-            bkg.plot(ax=ax_bkg)
-        except IndexError:
+        if "bkg" in self.available_hdus:
+            bkg = self.bkg
+
+            if not bkg.has_offset_axis:
+                bkg = bkg.to_2d()
+
+            bkg.plot(ax=axes_dict["bkg"])
+            axes_dict["bkg"].set_title("Background rate")
+        else:
             logging.warning(f"No background model found for obs {self.obs_id}.")
 
-        self.psf.plot_containment_vs_energy(ax=ax_psf)
-        self.edisp.plot_bias(ax=ax_edisp, add_cbar=True)
+        if "psf" in self.available_hdus:
+            self.psf.plot_containment_radius_vs_energy(ax=axes_dict["psf"])
+            axes_dict["psf"].set_title("Point spread function")
+        else:
+            logging.warning(f"No PSF found for obs {self.obs_id}.")
 
-        ax_aeff.set_title("Effective area")
-        ax_bkg.set_title("Background rate")
-        ax_psf.set_title("Point spread function")
-        ax_edisp.set_title("Energy dispersion")
+        if "edisp" in self.available_hdus:
+            self.edisp.plot_bias(ax=axes_dict["edisp"], add_cbar=True)
+            axes_dict["edisp"].set_title("Energy dispersion")
+        else:
+            logging.warning(f"No energy dispersion found for obs {self.obs_id}.")
 
     def select_time(self, time_interval):
         """Select a time interval of the observation.
@@ -381,6 +412,83 @@ class Observation:
         obs.obs_filter = new_obs_filter
         return obs
 
+    @classmethod
+    def read(cls, event_file, irf_file=None):
+        """Create an Observation from a Event List and an (optional) IRF file.
+
+        Parameters
+        ----------
+        event_file : str, Path
+            path to the .fits file containing the event list and the GTI
+        irf_file : str, Path
+            (optional) path to the .fits file containing the IRF components,
+            if not provided the IRF will be read from the event file
+
+        Returns
+        -------
+        observation : `~gammapy.data.Observation`
+            observation with the events and the irf read from the file
+        """
+        from gammapy.irf.io import load_irf_dict_from_file
+
+        events = EventList.read(event_file)
+
+        gti = GTI.read(event_file)
+
+        irf_file = irf_file if irf_file is not None else event_file
+        irf_dict = load_irf_dict_from_file(irf_file)
+
+        obs_info = events.table.meta
+        return cls(
+            events=events,
+            gti=gti,
+            obs_info=obs_info,
+            obs_id=obs_info.get("OBS_ID"),
+            **irf_dict,
+        )
+
+    def write(self, path, overwrite=False, format="gadf", include_irfs=True):
+        """
+        Write this observation into `path` using the specified format
+
+        Parameters
+        ----------
+        path: str or `~pathlib.Path`
+            Path for the output file
+        overwrite: bool
+            If true, existing files are overwritten.
+        format: str
+            Output format, currently only "gadf" is supported
+        include_irfs: bool
+            Whether to include irf components in the output file
+        """
+        if format != "gadf":
+            raise ValueError(f'Only the "gadf" format supported, got {format}')
+
+        path = make_path(path)
+
+        primary = fits.PrimaryHDU()
+        primary.header["CREATOR"] = f"Gammapy {__version__}"
+        primary.header["DATE"] = Time.now().iso
+
+        hdul = fits.HDUList([primary])
+
+        events = self.events
+        if events is not None:
+            hdul.append(events.to_table_hdu(format=format))
+
+        gti = self.gti
+        if gti is not None:
+            hdul.append(gti.to_table_hdu(format=format))
+
+        if include_irfs:
+            for irf_name in self.available_irfs:
+                irf = getattr(self, irf_name)
+                if irf is not None:
+                    hdul.append(irf.to_table_hdu(format="gadf-dl3"))
+
+        hdul.writeto(path, overwrite=overwrite)
+
 
 class Observations(collections.abc.MutableSequence):
     """Container class that holds a list of observations.
@@ -595,12 +703,3 @@ class ObservationChecker(Checker):
         except Exception:
             yield self._record(level="warning", msg="Loading psf failed")
             return
-
-        # TODO: implement some basic check
-        # The following doesn't work, because EnergyDependentMultiGaussPSF
-        # has no attribute `data`
-        # Check that data isn't all null
-        # if np.max(psf.data.data) <= 0:
-        #     yield self._record(
-        #         level="error", msg="maximum entry of psf is <= 0"
-        #     )
