@@ -95,13 +95,15 @@ def make_gti(times, time_ref="2010-01-01"):
 def test_gti_stack():
     time_ref = Time("2010-01-01")
     gti1 = make_gti({"START": [0, 2], "STOP": [1, 3]}, time_ref=time_ref)
+    gt1_pre_stack = gti1.copy()
     gti2 = make_gti({"START": [4], "STOP": [5]}, time_ref=time_ref + 10 * u.s)
 
-    gti = gti1.stack(gti2)
+    gti1.stack(gti2)
 
-    assert_time_allclose(gti.time_ref, gti1.time_ref)
-    assert_allclose(gti.table["START"], [0, 2, 14])
-    assert_allclose(gti.table["STOP"], [1, 3, 15])
+    assert len(gti1.table) == 3
+    assert_time_allclose(gt1_pre_stack.time_ref, gti1.time_ref)
+    assert_allclose(gti1.table["START"], [0, 2, 14])
+    assert_allclose(gti1.table["STOP"], [1, 3, 15])
 
 
 def test_gti_union():
@@ -134,3 +136,14 @@ def test_gti_write(tmp_path):
     assert_time_allclose(new_gti.time_start, gti.time_start)
     assert_time_allclose(new_gti.time_stop, gti.time_stop)
     assert new_gti.table.meta["MJDREFF"] == gti.table.meta["MJDREFF"]
+
+
+def test_gti_from_time():
+    """Test astropy time is supported as input for GTI.create"""
+    start = Time("2020-01-01T20:00:00")
+    stop = Time("2020-01-01T20:15:00")
+    ref = Time("2020-01-01T00:00:00")
+    gti = GTI.create(start, stop, ref)
+
+    assert u.isclose(gti.table["START"], 20 * u.hour)
+    assert u.isclose(gti.table["STOP"], 20 * u.hour + 15 * u.min)
