@@ -5,6 +5,7 @@ import astropy.units as u
 from astropy.io import fits
 from astropy.table import Table
 from regions import CircleSkyRegion
+import matplotlib.pyplot as plt
 from gammapy.data import GTI
 from gammapy.irf import EDispKernelMap, EDispMap, PSFKernel, PSFMap
 from gammapy.maps import Map, MapAxis
@@ -99,12 +100,9 @@ def create_map_dataset_geoms(
 
 
 class MapDataset(Dataset):
-    """Perform sky model likelihood fit on maps.
-
-    If an `HDULocation` is passed the map is loaded lazily. This means the
-    map data is only loaded in memory as the corresponding data attribute
-    on the MapDataset is accessed. If it was accessed once it is cached for
-    the next time.
+    """
+    Bundle together binned counts, background, IRFs, models and compute a likelihood.
+     Uses Cash statistics by default.
 
     Parameters
     ----------
@@ -130,6 +128,42 @@ class MapDataset(Dataset):
         Table listing information on observations used to create the dataset.
         One line per observation for stacked datasets.
 
+    If an `HDULocation` is passed the map is loaded lazily. This means the
+    map data is only loaded in memory as the corresponding data attribute
+    on the MapDataset is accessed. If it was accessed once it is cached for
+    the next time.
+
+    Examples
+    --------
+    >>> from gammapy.datasets import MapDataset
+    >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz", name="cta_dataset")
+    >>> print(dataset)
+    MapDataset
+    ----------
+    <BLANKLINE>
+      Name                            : cta_dataset
+    <BLANKLINE>
+      Total counts                    : 104317
+      Total background counts         : 91507.70
+      Total excess counts             : 12809.30
+    <BLANKLINE>
+      Predicted counts                : 91507.69
+      Predicted background counts     : 91507.70
+      Predicted excess counts         : nan
+    <BLANKLINE>
+      Exposure min                    : 6.28e+07 m2 s
+      Exposure max                    : 1.90e+10 m2 s
+    <BLANKLINE>
+      Number of total bins            : 768000
+      Number of fit bins              : 691680
+    <BLANKLINE>
+      Fit statistic type              : cash
+      Fit statistic value (-2 log(L)) : nan
+    <BLANKLINE>
+      Number of models                : 0
+      Number of parameters            : 0
+      Number of free parameters       : 0
+
 
     See Also
     --------
@@ -279,12 +313,12 @@ class MapDataset(Dataset):
 
     @property
     def models(self):
-        """Models (`~gammapy.modeling.models.Models`)."""
+        """Models set on the dataset (`~gammapy.modeling.models.Models`)."""
         return self._models
 
     @property
     def excess(self):
-        """Excess"""
+        """Observed excess: counts-background"""
         return self.counts - self.background
 
     @models.setter
@@ -381,8 +415,14 @@ class MapDataset(Dataset):
         """Energy range maps defined by the mask_fit only."""
         return self._energy_range(self.mask_fit)
 
+    @property
+    def energy_range_total(self):
+        """Largest energy range among all pixels, defined by the full mask (mask_safe and mask_fit)."""
+        energy_min_map, energy_max_map = self.energy_range
+        return np.nanmin(energy_min_map.quantity), np.nanmax(energy_max_map.quantity)
+
     def npred(self):
-        """Predicted source and background counts
+        """Total predicted source and background counts
 
         Returns
         -------
@@ -393,7 +433,7 @@ class MapDataset(Dataset):
 
         if self.background:
             npred_total += self.npred_background()
-
+        npred_total.data[npred_total.data < 0.0] = 0
         return npred_total
 
     def npred_background(self):
@@ -414,8 +454,9 @@ class MapDataset(Dataset):
                 if self._background_cached is None:
                     self._background_cached = background * values
                 else:
-                    self._background_cached.data = background.data * values.value
-                    self._background_cached.unit = background.unit
+                    self._background_cached.quantity = (
+                        background.quantity * values.value
+                    )
             return self._background_cached
         else:
             return background
@@ -431,20 +472,20 @@ class MapDataset(Dataset):
         return changed
 
     def npred_signal(self, model_name=None):
-        """ "Model predicted signal counts.
+        """Model predicted signal counts.
 
-        If a model is passed, predicted counts from that component is returned.
+        If a model name is passed, predicted counts from that component are returned.
         Else, the total signal counts are returned.
 
         Parameters
-        -------------
+        ----------
         model_name: str
             Name of  SkyModel for which to compute the npred for.
             If none, the sum of all components (minus the background model)
             is returned
 
         Returns
-        ----------
+        -------
         npred_sig: `gammapy.maps.Map`
             Map of the predicted signal counts
         """
@@ -569,7 +610,19 @@ class MapDataset(Dataset):
         -------
         empty_maps : `MapDataset`
             A MapDataset containing zero filled maps
+
+        Examples
+        --------
+        >>> from gammapy.datasets import MapDataset
+        >>> from gammapy.maps import WcsGeom, MapAxis
+
+        >>> energy_axis = MapAxis.from_energy_bounds(1.0, 10.0, 4, unit="TeV")
+        >>> energy_axis_true = MapAxis.from_energy_bounds( 0.5, 20, 10, unit="TeV", name="energy_true")
+        >>> geom = WcsGeom.create(skydir=(83.633, 22.014), binsz=0.02, width=(2, 2), frame="icrs", proj="CAR", axes=[energy_axis])
+
+        >>> empty = MapDataset.create(geom=geom, energy_axis_true=energy_axis_true, name="empty")
         """
+
         geoms = create_map_dataset_geoms(
             geom=geom,
             energy_axis_true=energy_axis_true,
@@ -640,6 +693,8 @@ class MapDataset(Dataset):
         ----------
         name : str
             Name of the masked dataset.
+        nan_to_num: bool
+            Non-finite values are replaced by zero if True (default).
 
         Returns
         -------
@@ -651,7 +706,7 @@ class MapDataset(Dataset):
         return dataset
 
     def stack(self, other, nan_to_num=True):
-        r"""Stack another dataset in place.
+        r"""Stack another dataset in place. The original dataset is modified.
 
         Safe mask is applied to compute the stacked counts data. Counts outside
         each dataset safe mask are lost.
@@ -818,6 +873,13 @@ class MapDataset(Dataset):
         -------
         ax : `~astropy.visualization.wcsaxes.WCSAxes`
             WCSAxes object.
+
+        Examples
+        --------
+        >>> from gammapy.datasets import MapDataset
+        >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz")
+        >>> kwargs = {"cmap": "RdBu_r", "vmin":-5, "vmax":5, "add_cbar": True}
+        >>> dataset.plot_residuals_spatial(method="diff/sqrt(model)", **kwargs) # doctest: +SKIP
         """
         counts, npred = self.counts.copy(), self.npred()
 
@@ -868,6 +930,14 @@ class MapDataset(Dataset):
         -------
         ax : `~matplotlib.axes.Axes`
             Axes object.
+
+        Examples
+        --------
+        >>> from gammapy.datasets import MapDataset
+        >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz")
+        >>> kwargs = {"markerfacecolor": "blue", "markersize":8, "marker":'s', } #plot big blue squares
+        >>> dataset.plot_residuals_spectral(method="diff/sqrt(model)", **kwargs) # doctest: +SKIP
+
         """
         counts, npred = self.counts.copy(), self.npred()
 
@@ -931,7 +1001,8 @@ class MapDataset(Dataset):
         Calls `~MapDataset.plot_residuals_spatial` and `~MapDataset.plot_residuals_spectral`.
         The spectral residuals are extracted from the provided region, and the
         normalization used for its computation can be controlled using the method
-        parameter. The region outline is overlaid on the residuals map.
+        parameter. The region outline is overlaid on the residuals map. If no region is passed,
+        the residuals are computed for the entire map
 
         Parameters
         ----------
@@ -941,13 +1012,26 @@ class MapDataset(Dataset):
             Axes to plot spectral residuals on.
         kwargs_spatial : dict
             Keyword arguments passed to `~MapDataset.plot_residuals_spatial`.
-        kwargs_spectral : dict (``region`` required)
+        kwargs_spectral : dict
             Keyword arguments passed to `~MapDataset.plot_residuals_spectral`.
+            The region should be passed as a dictionary key
 
         Returns
         -------
         ax_spatial, ax_spectral : `~astropy.visualization.wcsaxes.WCSAxes`, `~matplotlib.axes.Axes`
             Spatial and spectral residuals plots.
+
+        Examples
+        --------
+        >>> from regions import CircleSkyRegion
+        >>> from astropy.coordinates import SkyCoord
+        >>> import astropy.units as u
+        >>> from gammapy.datasets import MapDataset
+        >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz")
+        >>> reg = CircleSkyRegion(SkyCoord(0,0, unit="deg", frame="galactic"), radius=1.0*u.deg)
+        >>> kwargs_spatial = {"cmap": "RdBu_r", "vmin":-5, "vmax":5, "add_cbar": True}
+        >>> kwargs_spectral = {"region":reg, "markerfacecolor": "blue", "markersize":8, "marker":'s'}
+        >>> dataset.plot_residuals(kwargs_spatial=kwargs_spatial, kwargs_spectral=kwargs_spectral) # doctest: +SKIP
         """
         ax_spatial, ax_spectral = get_axes(
             ax_spatial,
@@ -959,14 +1043,16 @@ class MapDataset(Dataset):
             {"projection": self._geom.to_image().wcs},
         )
         kwargs_spatial = kwargs_spatial or {}
+        kwargs_spectral = kwargs_spectral or {}
 
         self.plot_residuals_spatial(ax_spatial, **kwargs_spatial)
         self.plot_residuals_spectral(ax_spectral, **kwargs_spectral)
 
         # Overlay spectral extraction region on the spatial residuals
-        region = kwargs_spectral["region"]
-        pix_region = region.to_pixel(self._geom.to_image().wcs)
-        pix_region.plot(ax=ax_spatial)
+        region = kwargs_spectral.get("region")
+        if region is not None:
+            pix_region = region.to_pixel(self._geom.to_image().wcs)
+            pix_region.plot(ax=ax_spatial)
 
         return ax_spatial, ax_spectral
 
@@ -1033,6 +1119,9 @@ class MapDataset(Dataset):
         if self.gti is not None:
             hdulist.append(fits.BinTableHDU(self.gti.table, name="GTI"))
 
+        if self.meta_table is not None:
+            hdulist.append(fits.BinTableHDU(self.meta_table, name="META_TABLE"))
+
         return hdulist
 
     @classmethod
@@ -1109,10 +1198,17 @@ class MapDataset(Dataset):
             gti = GTI(Table.read(hdulist, hdu="GTI"))
             kwargs["gti"] = gti
 
+        if "META_TABLE" in hdulist:
+            meta_table = Table.read(hdulist, hdu="META_TABLE")
+            kwargs["meta_table"] = meta_table
+
         return cls(**kwargs)
 
     def write(self, filename, overwrite=False):
-        """Write map dataset to file.
+        """Write Dataset to file.
+
+        A MapDataset is serialised using the GADF format with a WCS geometry.
+        A SpectrumDataset uses the same format, with a RegionGeom.
 
         Parameters
         ----------
@@ -1164,7 +1260,7 @@ class MapDataset(Dataset):
 
     @classmethod
     def read(cls, filename, name=None, lazy=False, cache=True, format="gadf"):
-        """Read map dataset from file.
+        """Read a dataset from file.
 
         Parameters
         ----------
@@ -1201,6 +1297,11 @@ class MapDataset(Dataset):
         dataset = cls.read(filename, name=data["name"], lazy=lazy, cache=cache)
         return dataset
 
+    @property
+    def _counts_statistic(self):
+        """Counts statistics of the dataset."""
+        return CashCountsStatistic(self.counts, self.background)
+
     def info_dict(self, in_safe_data_range=True):
         """Info dict with summary statistics, summed over energy
 
@@ -1223,20 +1324,21 @@ class MapDataset(Dataset):
             mask = slice(None)
 
         counts = 0
+        background, excess, sqrt_ts = np.nan, np.nan, np.nan
         if self.counts:
-            counts = self.counts.data[mask].sum()
+            summed_stat = self._counts_statistic[mask].sum()
+            counts = summed_stat.n_on
+
+            if self.background:
+                background = summed_stat.n_bkg
+                excess = summed_stat.n_sig
+                sqrt_ts = summed_stat.sqrt_ts
 
         info["counts"] = int(counts)
-
-        background = np.nan
-        if self.background:
-            background = self.background.data[mask].sum()
-
+        info["excess"] = float(excess)
+        info["sqrt_ts"] = sqrt_ts
         info["background"] = float(background)
 
-        info["excess"] = counts - background
-        info["sqrt_ts"] = CashCountsStatistic(counts, background).sqrt_ts
-
         npred = np.nan
         if self.models or not np.isnan(background):
             npred = self.npred().data[mask].sum()
@@ -1607,6 +1709,23 @@ class MapDataset(Dataset):
         -------
         dataset : `MapDataset` or `SpectrumDataset`
             Sliced dataset
+
+        Examples
+        --------
+        >>> from gammapy.datasets import MapDataset
+        >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz")
+        >>> slices = {"energy": slice(0, 3)} #to get the first 3 energy slices
+        >>> sliced = dataset.slice_by_idx(slices)
+        >>> print(sliced.geoms["geom"])
+        WcsGeom
+                axes       : ['lon', 'lat', 'energy']
+                shape      : (320, 240, 3)
+                ndim       : 3
+                frame      : galactic
+                projection : CAR
+                center     : 0.0 deg, 0.0 deg
+                width      : 8.0 deg x 6.0 deg
+                wcs ref    : 0.0 deg, 0.0 deg
         """
         name = make_name(name)
         kwargs = {"gti": self.gti, "name": name, "meta_table": self.meta_table}
@@ -1649,6 +1768,13 @@ class MapDataset(Dataset):
         dataset : `MapDataset`
             Sliced Dataset
 
+        Examples
+        --------
+        >>> from gammapy.datasets import MapDataset
+        >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz")
+        >>> sliced = dataset.slice_by_energy(energy_min="1 TeV", energy_max="5 TeV")
+        >>> sliced.data_shape
+        (3, 240, 320)
         """
         name = make_name(name)
 
@@ -1756,21 +1882,15 @@ class MapDataset(Dataset):
 
         Parameters
         ----------
-        fig : `~matplotlib.figure.Figure`
-            Figure to add AxesSubplot on.
+        figsize : tuple
+            Size of the figure.
 
-        Returns
-        -------
-        ax1, ax2, ax3 : `~matplotlib.axes.AxesSubplot`
-            Counts, excess and exposure.
         """
 
         def plot_mask(ax, mask, **kwargs):
             if mask is not None:
                 mask.plot_mask(ax=ax, **kwargs)
 
-        import matplotlib.pyplot as plt
-
         fig, axes = plt.subplots(
             ncols=2,
             nrows=2,
@@ -1801,7 +1921,7 @@ class MapDataset(Dataset):
 
 
 class MapDatasetOnOff(MapDataset):
-    """Map dataset for on-off likelihood fitting.
+    """Map dataset for on-off likelihood fitting. Uses wstat statistics.
 
     Parameters
     ----------
@@ -1929,7 +2049,7 @@ class MapDatasetOnOff(MapDataset):
         return alpha
 
     def npred_background(self):
-        """Prediced background counts estimated from the marginalized likelihood estimate.
+        """Predicted background counts (mu_bkg) estimated from the marginalized likelihood estimate.
 
         See :ref:`wstat`
 
@@ -1948,7 +2068,7 @@ class MapDatasetOnOff(MapDataset):
         return Map.from_geom(geom=self._geom, data=mu_bkg)
 
     def npred_off(self):
-        """Predicted counts in the off region
+        """Predicted counts in the off region; mu_bkg/alpha
 
         See :ref:`wstat`
 
@@ -1970,6 +2090,8 @@ class MapDatasetOnOff(MapDataset):
         background : `Map`
             Background map
         """
+        if self.counts_off is None:
+            return None
         return self.alpha * self.counts_off
 
     def stat_array(self):
@@ -1983,6 +2105,11 @@ class MapDatasetOnOff(MapDataset):
         )
         return np.nan_to_num(on_stat_)
 
+    @property
+    def _counts_statistic(self):
+        """Counts statistics of the dataset."""
+        return WStatCountsStatistic(self.counts, self.counts_off, self.alpha)
+
     @classmethod
     def from_geoms(
         cls,
@@ -2090,7 +2217,7 @@ class MapDatasetOnOff(MapDataset):
 
     def to_map_dataset(self, name=None):
         """Convert a MapDatasetOnOff to  MapDataset
-        The background model template is taken as alpha*counts_off
+        The background model template is taken as alpha * counts_off
 
         Parameters
         ----------
@@ -2252,6 +2379,12 @@ class MapDatasetOnOff(MapDataset):
 
         return hdulist
 
+    @classmethod
+    def _read_lazy(cls, filename, name=None, cache=True, format="gadf"):
+        raise NotImplementedError(
+            f"Lazy loading is not implemented for {cls}, please use option lazy=False."
+        )
+
     @classmethod
     def from_hdulist(cls, hdulist, name=None, format="gadf"):
         """Create map dataset from list of HDUs.
@@ -2332,6 +2465,10 @@ class MapDatasetOnOff(MapDataset):
         if "GTI" in hdulist:
             gti = GTI(Table.read(hdulist, hdu="GTI"))
             kwargs["gti"] = gti
+
+        if "META_TABLE" in hdulist:
+            meta_table = Table.read(hdulist, hdu="META_TABLE")
+            kwargs["meta_table"] = meta_table
         return cls(**kwargs)
 
     def info_dict(self, in_safe_data_range=True):
@@ -2358,36 +2495,30 @@ class MapDatasetOnOff(MapDataset):
         else:
             mask = slice(None)
 
+        summed_stat = self._counts_statistic[mask].sum()
+
         counts_off = 0
         if self.counts_off is not None:
-            counts_off = self.counts_off.data[mask].sum()
+            counts_off = summed_stat.n_off
 
         info["counts_off"] = int(counts_off)
 
         acceptance = 1
         if self.acceptance:
-            # TODO: handle energy dependent a_on / a_off
             acceptance = self.acceptance.data[mask].sum()
 
         info["acceptance"] = float(acceptance)
 
         acceptance_off = np.nan
+        alpha = np.nan
+
         if self.acceptance_off:
-            acceptance_off = acceptance * counts_off / info["background"]
+            alpha = summed_stat.alpha
+            acceptance_off = acceptance / alpha
 
         info["acceptance_off"] = float(acceptance_off)
-
-        alpha = np.nan
-        if self.acceptance_off and self.acceptance:
-            alpha = np.mean(self.alpha.data[mask])
-
         info["alpha"] = float(alpha)
 
-        info["sqrt_ts"] = WStatCountsStatistic(
-            info["counts"],
-            info["counts_off"],
-            acceptance / acceptance_off,
-        ).sqrt_ts
         info["stat_sum"] = self.stat_sum()
         return info
 
