@@ -13,7 +13,6 @@ from gammapy.maps import MapAxis, RegionGeom, RegionNDMap, WcsGeom
 from gammapy.modeling import Fit
 from gammapy.modeling.models import (
     ConstantSpectralModel,
-    ConstantTemporalModel,
     ExpCutoffPowerLawSpectralModel,
     Models,
     PowerLawSpectralModel,
@@ -21,57 +20,10 @@ from gammapy.modeling.models import (
 )
 from gammapy.utils.random import get_random_state
 from gammapy.utils.regions import compound_region_to_regions
-from gammapy.utils.testing import (
-    assert_time_allclose,
-    mpl_plot_check,
-    requires_data,
-    requires_dependency,
-)
+from gammapy.utils.testing import assert_time_allclose, mpl_plot_check, requires_data
 from gammapy.utils.time import time_ref_to_dict
 
 
-@pytest.fixture()
-def spectrum_dataset():
-    name = "test"
-    energy = np.logspace(-1, 1, 31) * u.TeV
-    livetime = 100 * u.s
-
-    pwl = PowerLawSpectralModel(
-        index=2.1,
-        amplitude="1e5 cm-2 s-1 TeV-1",
-        reference="0.1 TeV",
-    )
-
-    temp_mod = ConstantTemporalModel()
-
-    model = SkyModel(spectral_model=pwl, temporal_model=temp_mod, name="test-source")
-    axis = MapAxis.from_edges(energy, interp="log", name="energy")
-    axis_true = MapAxis.from_edges(energy, interp="log", name="energy_true")
-
-    background = RegionNDMap.create(region="icrs;circle(0, 0, 0.1)", axes=[axis])
-
-    models = Models([model])
-    exposure = RegionNDMap.create(region="icrs;circle(0, 0, 0.1)", axes=[axis_true])
-    exposure.quantity = u.Quantity("1 cm2") * livetime
-    bkg_rate = np.ones(30) / u.s
-    background.quantity = bkg_rate * livetime
-
-    start = [1, 3, 5] * u.day
-    stop = [2, 3.5, 6] * u.day
-    t_ref = Time(55555, format="mjd")
-    gti = GTI.create(start, stop, reference_time=t_ref)
-
-    dataset = SpectrumDataset(
-        models=models,
-        exposure=exposure,
-        background=background,
-        name=name,
-        gti=gti,
-    )
-    dataset.fake(random_state=23)
-    return dataset
-
-
 def test_data_shape(spectrum_dataset):
     assert spectrum_dataset.data_shape[0] == 30
 
@@ -113,6 +65,46 @@ def test_set_model(spectrum_dataset):
     assert spectrum_dataset.models["test"] is model
 
 
+def test_spectrum_dataset_fits_io(spectrum_dataset, tmp_path):
+    spectrum_dataset.meta_table = Table(
+        data=[[1.0 * u.h], [111]], names=["livetime", "obs_id"]
+    )
+    hdulist = spectrum_dataset.to_hdulist()
+    actual = [hdu.name for hdu in hdulist]
+    desired = [
+        "PRIMARY",
+        "COUNTS",
+        "COUNTS_BANDS",
+        "COUNTS_REGION",
+        "EXPOSURE",
+        "EXPOSURE_BANDS",
+        "EXPOSURE_REGION",
+        "BACKGROUND",
+        "BACKGROUND_BANDS",
+        "BACKGROUND_REGION",
+        "GTI",
+        "META_TABLE",
+    ]
+
+    assert actual == desired
+
+    spectrum_dataset.write(tmp_path / "test.fits")
+    dataset_new = SpectrumDataset.read(tmp_path / "test.fits", name="test")
+
+    assert_allclose(spectrum_dataset.counts.data, dataset_new.counts.data)
+    assert_allclose(
+        spectrum_dataset.npred_background().data, dataset_new.npred_background().data
+    )
+    assert dataset_new.edisp is None
+    assert dataset_new.edisp is None
+    assert dataset_new.name == "test"
+
+    assert_allclose(spectrum_dataset.exposure.data, dataset_new.exposure.data)
+    assert spectrum_dataset.counts.geom == dataset_new.counts.geom
+
+    assert_allclose(dataset_new.meta_table["obs_id"], 111)
+
+
 def test_npred_models():
     e_reco = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=3)
 
@@ -152,7 +144,6 @@ def test_npred_spatial_model(spectrum_dataset):
     assert spectrum_dataset.evaluators["test"].psf is None
 
 
-@requires_dependency("iminuit")
 def test_fit(spectrum_dataset):
     """Simple CASH fit to the on vector"""
     fit = Fit()
@@ -343,7 +334,6 @@ def test_spectrum_dataset_stack_nondiagonal_no_bkg(spectrum_dataset):
     assert_allclose(kernel.get_resolution(1 * u.TeV), 0.1581, atol=1e-2)
 
 
-@requires_dependency("matplotlib")
 def test_peek(spectrum_dataset):
     with mpl_plot_check():
         spectrum_dataset.peek()
@@ -498,7 +488,6 @@ class TestSpectrumOnOff:
         assert isinstance(ds, SpectrumDataset)
         assert_allclose(ds.background.data.sum(), 4)
 
-    @requires_dependency("matplotlib")
     def test_peek(self):
         dataset = self.dataset.copy()
         dataset.models = SkyModel(spectral_model=PowerLawSpectralModel())
@@ -506,7 +495,6 @@ class TestSpectrumOnOff:
         with mpl_plot_check():
             dataset.peek()
 
-    @requires_dependency("matplotlib")
     def test_plot_fit(self):
         dataset = self.dataset.copy()
         dataset.models = SkyModel(spectral_model=PowerLawSpectralModel())
@@ -514,7 +502,6 @@ class TestSpectrumOnOff:
         with mpl_plot_check():
             dataset.plot_fit()
 
-    @requires_dependency("matplotlib")
     def test_plot_off_regions(self):
         from gammapy.visualization import plot_spectrum_datasets_off_regions
 
@@ -584,6 +571,13 @@ class TestSpectrumOnOff:
         assert newdataset.edisp is None
         assert newdataset.gti is None
 
+    def test_spectrum_dataset_onoff_fits_io(self, tmp_path):
+        self.dataset.write(tmp_path / "test.fits", format="gadf")
+        d1 = SpectrumDatasetOnOff.read(tmp_path / "test.fits", format="gadf")
+        assert isinstance(d1.counts.geom, RegionGeom)
+        assert d1.exposure == self.dataset.exposure
+        assert_allclose(d1.counts_off.data, self.dataset.counts_off.data)
+
     def test_energy_mask(self):
         mask = self.dataset.counts.geom.energy_mask(
             energy_min=0.3 * u.TeV, energy_max=6 * u.TeV
@@ -679,7 +673,6 @@ class TestSpectrumOnOff:
 
 
 @requires_data()
-@requires_dependency("iminuit")
 class TestSpectralFit:
     """Test fit in astrophysical scenario"""
 
@@ -714,7 +707,6 @@ class TestSpectralFit:
         for obs in self.datasets:
             obs.models = model
 
-    @requires_dependency("iminuit")
     def test_basic_results(self):
         self.set_model(self.pwl)
         result = self.fit.run([self.datasets[0]])
@@ -731,7 +723,7 @@ class TestSpectralFit:
 
     def test_basic_errors(self):
         self.set_model(self.pwl)
-        result = self.fit.run([self.datasets[0]])
+        self.fit.run([self.datasets[0]])
         pars = self.pwl.parameters
 
         assert_allclose(pars["index"].error, 0.149633, rtol=1e-3)
@@ -785,7 +777,7 @@ class TestSpectralFit:
         dataset.models = self.pwl
 
         fit = Fit()
-        result = fit.run(datasets=[dataset])
+        fit.run(datasets=[dataset])
         assert_allclose(self.pwl.spectral_model.index.value, 2.7961, atol=0.02)
 
     def test_stacked_fit(self):
@@ -794,7 +786,7 @@ class TestSpectralFit:
         dataset.models = SkyModel(PowerLawSpectralModel())
 
         fit = Fit()
-        result = fit.run(datasets=[dataset])
+        fit.run(datasets=[dataset])
         pars = dataset.models.parameters
 
         assert_allclose(pars["index"].value, 2.7767, rtol=1e-3)
@@ -1050,7 +1042,6 @@ def test_spectrum_dataset_on_off_to_yaml(tmpdir):
     assert datasets_read[1].counts.data.sum() == datasets[1].counts.data.sum()
 
 
-@requires_dependency("iminuit")
 class TestFit:
     """Test fit on counts spectra without any IRFs"""
 
@@ -1101,7 +1092,7 @@ class TestFit:
         self.source_model.parameters["index"].value = 1.12
 
         fit = Fit()
-        result = fit.run(datasets=[dataset])
+        fit.run(datasets=[dataset])
 
         # These values are check with sherpa fits, do not change
         pars = self.source_model.parameters
@@ -1160,7 +1151,7 @@ class TestFit:
             mask_safe=mask_safe,
         )
         fit = Fit()
-        result = fit.run(datasets=[dataset])
+        fit.run(datasets=[dataset])
         true_idx = self.source_model.parameters["index"].value
 
         values = np.linspace(0.95 * true_idx, 1.05 * true_idx, 100)
