@@ -2,6 +2,7 @@
 import numpy as np
 from astropy import units as u
 from astropy.visualization import quantity_support
+import matplotlib.pyplot as plt
 from gammapy.utils.array import array_stats_str
 from ..core import IRF
 
@@ -139,8 +140,6 @@ class PSF(IRF):
              Axes to plot on.
 
         """
-        import matplotlib.pyplot as plt
-
         ax = plt.gca() if ax is None else ax
 
         energy_true = self.axes["energy_true"]
@@ -179,8 +178,6 @@ class PSF(IRF):
         ax : `~matplotlib.pyplot.Axes`
              Axes to plot on.
         """
-        import matplotlib.pyplot as plt
-
         ax = plt.gca() if ax is None else ax
 
         energy = self.axes["energy_true"]
@@ -228,7 +225,6 @@ class PSF(IRF):
             True energy at which to plot the profile
 
         """
-        import matplotlib.pyplot as plt
         from gammapy.datasets.map import RAD_AXIS_DEFAULT
 
         ax = plt.gca() if ax is None else ax
@@ -255,9 +251,14 @@ class PSF(IRF):
         return ax
 
     def peek(self, figsize=(15, 5)):
-        """Quick-look summary plots."""
-        import matplotlib.pyplot as plt
+        """Quick-look summary plots.
 
+        Parameters
+        ----------
+        figsize : tuple
+            Size of the figure.
+
+        """
         fig, axes = plt.subplots(nrows=1, ncols=3, figsize=figsize)
 
         self.plot_containment_radius(fraction=0.68, ax=axes[0])
