@@ -32,11 +32,12 @@ class SafeMaskMaker(Maker):
         Percentage of the energy bias to be used as lower
         energy threshold for method "edisp-bias"
     position : `~astropy.coordinates.SkyCoord`
-        Position at which the `aeff_percent` or `bias_percent` are computed. By default,
-        it uses the position of the center of the map.
+        Position at which the `aeff_percent` or `bias_percent` are computed.
     fixed_offset : `~astropy.coordinates.Angle`
         offset, calculated from the pointing position, at which
         the `aeff_percent` or `bias_percent` are computed.
+        If neither the position nor fixed_offset is specified,
+        it uses the position of the center of the map by default.
     offset_max : str or `~astropy.units.Quantity`
         Maximum offset cut.
     """
@@ -116,12 +117,23 @@ class SafeMaskMaker(Maker):
         if observation is None:
             raise ValueError("Method 'offset-max' requires an observation object.")
 
-        try:
-            energy_max = observation.aeff.meta["HI_THRES"] * u.TeV
-            energy_min = observation.aeff.meta["LO_THRES"] * u.TeV
-        except KeyError:
-            log.warning(f"No default thresholds defined for obs {observation.obs_id}")
-            energy_min, energy_max = None, None
+        energy_max = observation.aeff.meta.get("HI_THRES", None)
+
+        if energy_max:
+            energy_max = energy_max * u.TeV
+        else:
+            log.warning(
+                f"No default upper safe energy threshold defined for obs {observation.obs_id}"
+            )
+
+        energy_min = observation.aeff.meta.get("LO_THRES", None)
+
+        if energy_min:
+            energy_min = energy_min * u.TeV
+        else:
+            log.warning(
+                f"No default lower safe energy threshold defined for obs {observation.obs_id}"
+            )
 
         return dataset._geom.energy_mask(energy_min=energy_min, energy_max=energy_max)
 
@@ -204,16 +216,18 @@ class SafeMaskMaker(Maker):
 
         if isinstance(edisp, EDispKernelMap):
             if position:
-                edisp = edisp.get_edisp_kernel(position)
+                edisp = edisp.get_edisp_kernel(position=position)
             else:
-                edisp = edisp.get_edisp_kernel(self.position)
+                edisp = edisp.get_edisp_kernel(position=self.position)
         else:
             if position:
                 e_reco = dataset._geom.axes["energy"].edges
-                edisp = edisp.get_edisp_kernel(position, e_reco)
+                edisp = edisp.get_edisp_kernel(position=position, energy_axis=e_reco)
             else:
                 e_reco = dataset._geom.axes["energy"].edges
-                edisp = edisp.get_edisp_kernel(self.position, e_reco)
+                edisp = edisp.get_edisp_kernel(
+                    position=self.position, energy_axis=e_reco
+                )
 
         energy_min = edisp.get_bias_energy(self.bias_percent / 100)
         return geom.energy_mask(energy_min=energy_min[0])
@@ -222,9 +236,11 @@ class SafeMaskMaker(Maker):
     def make_mask_energy_bkg_peak(dataset):
         """Make safe energy mask based on the binned background.
 
-        The energy threshold is defined as the upper edge of the energy
-        bin with the highest predicted background rate. This method is motivated
-        by its use in the HESS DL3 validation paper: https://arxiv.org/pdf/1910.08088.pdf
+        The energy threshold is defined as the lower edge of the energy
+        bin with the highest predicted background rate. This is to ensure analysis in
+        a region where a  Powerlaw approximation to the background spectrum is valid.
+        The is motivated by its use in the HESS DL3
+        validation paper: https://arxiv.org/pdf/1910.08088.pdf
 
         Parameters
         ----------
@@ -240,7 +256,7 @@ class SafeMaskMaker(Maker):
         background_spectrum = dataset.npred_background().get_spectrum()
         idx = np.argmax(background_spectrum.data, axis=0)
         energy_axis = geom.axes["energy"]
-        energy_min = energy_axis.pix_to_coord(idx)
+        energy_min = energy_axis.edges[idx]
         return geom.energy_mask(energy_min=energy_min)
 
     @staticmethod
@@ -280,7 +296,11 @@ class SafeMaskMaker(Maker):
         dataset : `Dataset`
             Dataset with defined safe range mask.
         """
-        mask_safe = np.ones(dataset._geom.data_shape, dtype=bool)
+
+        if dataset.mask_safe:
+            mask_safe = dataset.mask_safe.data
+        else:
+            mask_safe = np.ones(dataset._geom.data_shape, dtype=bool)
 
         if dataset.background is not None:
             # apply it first so only clipped values are removed for "bkg-peak"
