@@ -389,7 +389,7 @@ class HpxGeom(Geom):
     @property
     def npix_max(self):
         """Max. number of pixels"""
-        maxpix = 12 * self.nside ** 2
+        maxpix = 12 * self.nside**2
         return maxpix * np.ones(self.shape_axes, dtype=int)
 
     @property
@@ -1377,27 +1377,48 @@ class HpxGeom(Geom):
             f"\tcenter     : {lon:.1f} deg, {lat:.1f} deg\n"
         )
 
-    def __eq__(self, other):
+    def is_allclose(self, other, rtol_axes=1e-6, atol_axes=1e-6):
+        """Compare two data IRFs for equivalency
+
+        Parameters
+        ----------
+        other :  `HpxGeom`
+            Geom to compare against
+        rtol_axes : float
+            Relative tolerance for the axes comparison.
+        atol_axes : float
+            Relative tolerance for the axes comparison.
+
+        Returns
+        -------
+        is_allclose : bool
+            Whether the geometry is all close.
+        """
         if not isinstance(other, self.__class__):
-            return NotImplemented
+            return TypeError(f"Cannot compare {type(self)} and {type(other)}")
 
         if self.is_allsky and not other.is_allsky:
-            return NotImplemented
+            return False
 
-        # check overall shape and axes compatibility
         if self.data_shape != other.data_shape:
             return False
 
-        for axis, otheraxis in zip(self.axes, other.axes):
-            if axis != otheraxis:
-                return False
+        axes_eq = self.axes.is_allclose(other.axes, rtol=rtol_axes, atol=atol_axes)
 
-        return (
+        hpx_eq = (
             self.nside == other.nside
             and self.frame == other.frame
             and self.order == other.order
             and self.nest == other.nest
         )
 
+        return axes_eq and hpx_eq
+
+    def __eq__(self, other):
+        if not isinstance(other, self.__class__):
+            return False
+
+        return self.is_allclose(other=other)
+
     def __ne__(self, other):
         return not self.__eq__(other)
