@@ -4,14 +4,22 @@ import numpy as np
 from astropy import units as u
 from astropy.coordinates import Angle, SkyCoord
 from astropy.io import fits
-from astropy.table import Table
+from astropy.table import QTable, Table
 from astropy.utils import lazyproperty
 from astropy.wcs.utils import (
     proj_plane_pixel_area,
     proj_plane_pixel_scales,
     wcs_to_celestial_frame,
 )
-from regions import CompoundSkyRegion, PixCoord, PointSkyRegion, Regions, SkyRegion
+from regions import (
+    CompoundSkyRegion,
+    PixCoord,
+    PointSkyRegion,
+    RectanglePixelRegion,
+    Regions,
+    SkyRegion,
+)
+import matplotlib.pyplot as plt
 from gammapy.utils.regions import (
     compound_region_center,
     compound_region_to_regions,
@@ -64,15 +72,15 @@ class RegionGeom(Geom):
 
         if wcs is None and region is not None:
             if isinstance(region, CompoundSkyRegion):
-                center = compound_region_center(region)
+                self._center = compound_region_center(region)
             else:
-                center = region.center
+                self._center = region.center
 
             wcs = WcsGeom.create(
                 binsz=binsz_wcs,
-                skydir=center,
+                skydir=self._center,
                 proj=self.projection,
-                frame=center.frame.name,
+                frame=self._center.frame.name,
             ).wcs
 
         self._wcs = wcs
@@ -121,7 +129,12 @@ class RegionGeom(Geom):
         for region_pix in regions_pix[1:]:
             bbox = bbox.union(region_pix.bounding_box)
 
-        rectangle_pix = bbox.to_region()
+        try:
+            rectangle_pix = bbox.to_region()
+        except ValueError:
+            rectangle_pix = RectanglePixelRegion(
+                center=PixCoord(*bbox.center[::-1]), width=1, height=1
+            )
         return rectangle_pix.to_sky(self.wcs)
 
     @property
@@ -143,6 +156,12 @@ class RegionGeom(Geom):
         of the region geometry"""
         return self._region
 
+    @property
+    def is_all_point_sky_regions(self):
+        """Whether regions are all point regions"""
+        regions = compound_region_to_regions(self.region)
+        return np.all([isinstance(_, PointSkyRegion) for _ in regions])
+
     @property
     def axes(self):
         """List of non-spatial axes."""
@@ -301,8 +320,21 @@ class RegionGeom(Geom):
         if self.region is None:
             raise ValueError("Region definition required.")
 
-        area = self.region.to_pixel(self.wcs).area
-        solid_angle = area * proj_plane_pixel_area(self.wcs) * u.deg ** 2
+        # compound regions do not implement area()
+        # so we use the mask represenation and estimate the area
+        # from the pixels in the mask using oversampling
+        if isinstance(self.region, CompoundSkyRegion):
+            # oversample by a factor of ten
+            oversampling = 10.0
+            wcs = self.to_binsz_wcs(self.binsz_wcs / oversampling).wcs
+            pixel_region = self.region.to_pixel(wcs)
+            mask = pixel_region.to_mask()
+            area = np.count_nonzero(mask) / oversampling**2
+        else:
+            # all other types of regions should implement area
+            area = self.region.to_pixel(self.wcs).area
+
+        solid_angle = area * proj_plane_pixel_area(self.wcs) * u.deg**2
         return solid_angle.to("sr")
 
     def bin_volume(self):
@@ -547,28 +579,52 @@ class RegionGeom(Geom):
             f"\tcenter     : {lon:.1f} deg, {lat:.1f} deg\n"
         )
 
-    def __eq__(self, other):
-        # check overall shape and axes compatibility
+    def is_allclose(self, other, rtol_axes=1e-6, atol_axes=1e-6):
+        """Compare two data IRFs for equivalency
+
+        Parameters
+        ----------
+        other : `RegionGeom`
+            Geom to compare against.
+        rtol_axes : float
+            Relative tolerance for the axes comparison.
+        atol_axes : float
+            Relative tolerance for the axes comparison.
+
+        Returns
+        -------
+        is_allclose : bool
+            Whether the geometry is all close.
+        """
+        if not isinstance(other, self.__class__):
+            return TypeError(f"Cannot compare {type(self)} and {type(other)}")
+
         if self.data_shape != other.data_shape:
             return False
 
-        for axis, otheraxis in zip(self.axes, other.axes):
-            if axis != otheraxis:
-                return False
+        axes_eq = self.axes.is_allclose(other.axes, rtol=rtol_axes, atol=atol_axes)
+        # TODO: compare regions based on masks...
+        regions_eq = True
+        return axes_eq and regions_eq
 
-        # TODO: compare regions
-        return True
+    def __eq__(self, other):
+        if not isinstance(other, self.__class__):
+            return False
+
+        return self.is_allclose(other=other)
 
     def _to_region_table(self):
         """Export region to a FITS region table."""
         if self.region is None:
             raise ValueError("Region definition required.")
 
-        # TODO: make this a to_hdulist() method
         region_list = compound_region_to_regions(self.region)
+
         pixel_region_list = []
+
         for reg in region_list:
             pixel_region_list.append(reg.to_pixel(self.wcs))
+
         table = Regions(pixel_region_list).serialize(format="fits")
 
         header = WcsGeom(wcs=self.wcs, npix=self.wcs.array_shape).to_header()
@@ -664,16 +720,23 @@ class RegionGeom(Geom):
             region_hdu = hdu + "_" + region_hdu
 
         if region_hdu in hdulist:
-            region_table = Table.read(hdulist[region_hdu])
-            wcs = WcsGeom.from_header(region_table.meta).wcs
+            try:
+                region_table = QTable.read(hdulist[region_hdu])
+                regions_pix = Regions.parse(data=region_table, format="fits")
+            except TypeError:
+                # TODO: this is needed to support regions=0.5
+                region_table = Table.read(hdulist[region_hdu])
+                regions_pix = Regions.parse(data=region_table, format="fits")
 
+            wcs = WcsGeom.from_header(region_table.meta).wcs
             regions = []
 
-            for reg in Regions.parse(data=region_table, format="fits"):
+            for region_pix in regions_pix:
                 # TODO: remove workaround once regions issue with fits serialization is sorted out
                 # see https://github.com/astropy/regions/issues/400
-                reg.meta["include"] = True
-                regions.append(reg.to_sky(wcs))
+                region_pix.meta["include"] = True
+                regions.append(region_pix.to_sky(wcs))
+
             region = regions_to_compound_region(regions)
         else:
             region, wcs = None, None
@@ -700,7 +763,7 @@ class RegionGeom(Geom):
             else:
                 self._region = other.region
 
-    def plot_region(self, ax=None, **kwargs):
+    def plot_region(self, ax=None, kwargs_point=None, path_effect=None, **kwargs):
         """Plot region in the sky.
 
         Parameters
@@ -709,6 +772,11 @@ class RegionGeom(Geom):
             Axes to plot on. If no axes are given,
             the region is shown using the minimal
             equivalent WCS geometry.
+        kwargs_point : dict
+            Keyword arguments passed to `~matplotlib.lines.Line2D` for plotting
+            of point sources
+        path_effect : `~matplotlib.patheffects.PathEffect`
+            Path effect applied to artists and lines.
         **kwargs : dict
             Keyword arguments forwarded to `~regions.PixelRegion.as_artist`
 
@@ -718,8 +786,8 @@ class RegionGeom(Geom):
             Axes to plot on.
         """
         from astropy.visualization.wcsaxes import WCSAxes
-        import matplotlib.pyplot as plt
-        from matplotlib.collections import PatchCollection
+
+        kwargs_point = kwargs_point or {}
 
         if ax is None:
             ax = plt.gca()
@@ -730,11 +798,22 @@ class RegionGeom(Geom):
                 m = Map.from_geom(wcs_geom.to_image())
                 ax = m.plot(add_cbar=False)
 
-        regions = compound_region_to_regions(self.region)
-        artists = [region.to_pixel(wcs=ax.wcs).as_artist() for region in regions]
-
         kwargs.setdefault("fc", "None")
+        kwargs.setdefault("ec", "tab:blue")
+        kwargs_point.setdefault("color", kwargs.get("edgecolor"))
+        kwargs_point.setdefault("marker", "*")
+
+        for region in compound_region_to_regions(self.region):
+            region_pix = region.to_pixel(wcs=ax.wcs)
+
+            if isinstance(region, PointSkyRegion):
+                artist = region_pix.as_artist(**kwargs_point)
+            else:
+                artist = region_pix.as_artist(**kwargs)
+
+            if path_effect:
+                artist.add_path_effect(path_effect)
+
+            ax.add_artist(artist)
 
-        patches = PatchCollection(artists, **kwargs)
-        ax.add_collection(patches)
         return ax
