@@ -1,6 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Spectral models for Gammapy."""
+import logging
 import operator
+import os
 import numpy as np
 import scipy.optimize
 import scipy.special
@@ -9,6 +11,7 @@ from astropy import constants as const
 from astropy.table import Table
 from astropy.utils.decorators import classproperty
 from astropy.visualization import quantity_support
+import matplotlib.pyplot as plt
 from gammapy.maps import MapAxis, RegionNDMap
 from gammapy.modeling import Parameter, Parameters
 from gammapy.utils.integrate import trapz_loglog
@@ -20,6 +23,36 @@ from gammapy.utils.roots import find_roots
 from gammapy.utils.scripts import make_path
 from .core import ModelBase
 
+log = logging.getLogger(__name__)
+
+
+__all__ = [
+    "BrokenPowerLawSpectralModel",
+    "CompoundSpectralModel",
+    "ConstantSpectralModel",
+    "EBLAbsorptionNormSpectralModel",
+    "ExpCutoffPowerLaw3FGLSpectralModel",
+    "ExpCutoffPowerLawNormSpectralModel",
+    "ExpCutoffPowerLawSpectralModel",
+    "GaussianSpectralModel",
+    "integrate_spectrum",
+    "LogParabolaNormSpectralModel",
+    "LogParabolaSpectralModel",
+    "NaimaSpectralModel",
+    "PiecewiseNormSpectralModel",
+    "PowerLaw2SpectralModel",
+    "PowerLawNormSpectralModel",
+    "PowerLawSpectralModel",
+    "scale_plot_flux",
+    "ScaleSpectralModel",
+    "SmoothBrokenPowerLawSpectralModel",
+    "SpectralModel",
+    "SuperExpCutoffPowerLaw3FGLSpectralModel",
+    "SuperExpCutoffPowerLaw4FGLDR3SpectralModel",
+    "SuperExpCutoffPowerLaw4FGLSpectralModel",
+    "TemplateSpectralModel",
+]
+
 
 def scale_plot_flux(flux, energy_power=0):
     """Scale flux to plot
@@ -42,7 +75,7 @@ def scale_plot_flux(flux, energy_power=0):
     except IndexError:
         eunit = energy.unit
     y = flux * np.power(energy, energy_power)
-    return y.to_unit(flux.unit * eunit ** energy_power)
+    return y.to_unit(flux.unit * eunit**energy_power)
 
 
 def integrate_spectrum(func, energy_min, energy_max, ndecade=100):
@@ -290,7 +323,7 @@ class SpectralModel(ModelBase):
             "ref_dnde": self(energy),
             "ref_flux": self.integral(energy_min, energy_max),
             "ref_eflux": self.energy_flux(energy_min, energy_max),
-            "ref_e2dnde": self(energy) * energy ** 2,
+            "ref_e2dnde": self(energy) * energy**2,
         }
 
     def _get_plot_flux(self, energy, sed_type):
@@ -301,7 +334,7 @@ class SpectralModel(ModelBase):
             flux.quantity, flux_err.quantity = self.evaluate_error(energy.center)
 
         elif sed_type == "e2dnde":
-            flux.quantity, flux_err.quantity = energy.center ** 2 * self.evaluate_error(
+            flux.quantity, flux_err.quantity = energy.center**2 * self.evaluate_error(
                 energy.center
             )
 
@@ -362,7 +395,6 @@ class SpectralModel(ModelBase):
         ax : `~matplotlib.axes.Axes`, optional
             Axis
         """
-        import matplotlib.pyplot as plt
         from gammapy.estimators.map.core import DEFAULT_UNIT
 
         ax = plt.gca() if ax is None else ax
@@ -377,9 +409,8 @@ class SpectralModel(ModelBase):
             n_points,
         )
 
-        kwargs.setdefault(
-            "yunits", DEFAULT_UNIT[sed_type] * energy.unit ** energy_power
-        )
+        if ax.yaxis.units is None:
+            ax.yaxis.set_units(DEFAULT_UNIT[sed_type] * energy.unit**energy_power)
 
         flux, _ = self._get_plot_flux(sed_type=sed_type, energy=energy)
 
@@ -436,7 +467,6 @@ class SpectralModel(ModelBase):
         ax : `~matplotlib.axes.Axes`, optional
             Axis
         """
-        import matplotlib.pyplot as plt
         from gammapy.estimators.map.core import DEFAULT_UNIT
 
         ax = plt.gca() if ax is None else ax
@@ -454,9 +484,9 @@ class SpectralModel(ModelBase):
         kwargs.setdefault("facecolor", "black")
         kwargs.setdefault("alpha", 0.2)
         kwargs.setdefault("linewidth", 0)
-        kwargs.setdefault(
-            "yunits", DEFAULT_UNIT[sed_type] * energy.unit ** energy_power
-        )
+
+        if ax.yaxis.units is None:
+            ax.yaxis.set_units(DEFAULT_UNIT[sed_type] * energy.unit**energy_power)
 
         flux, flux_err = self._get_plot_flux(sed_type=sed_type, energy=energy)
         y_lo = scale_plot_flux(flux - flux_err, energy_power).quantity[:, 0, 0]
@@ -570,7 +600,7 @@ class ConstantSpectralModel(SpectralModel):
     """
 
     tag = ["ConstantSpectralModel", "const"]
-    const = Parameter("const", "1e-12 cm-2 s-1 TeV-1")
+    const = Parameter("const", "1e-12 cm-2 s-1 TeV-1", is_norm=True)
 
     @staticmethod
     def evaluate(energy, const):
@@ -656,7 +686,11 @@ class PowerLawSpectralModel(SpectralModel):
     tag = ["PowerLawSpectralModel", "pl"]
     index = Parameter("index", 2.0)
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1 TeV-1", scale_method="scale10", interp="log"
+        "amplitude",
+        "1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     reference = Parameter("reference", "1 TeV", frozen=True)
 
@@ -711,7 +745,7 @@ class PowerLawSpectralModel(SpectralModel):
         """
         val = -1 * index + 2
 
-        prefactor = amplitude * reference ** 2 / val
+        prefactor = amplitude * reference**2 / val
         upper = (energy_max / reference) ** val
         lower = (energy_min / reference) ** val
         energy_flux = prefactor * (upper - lower)
@@ -722,7 +756,7 @@ class PowerLawSpectralModel(SpectralModel):
             # see https://www.wolframalpha.com/input/?i=a+*+x+*+(x%2Fb)+%5E+(-2)
             # for reference
             energy_flux[mask] = (
-                amplitude * reference ** 2 * np.log(energy_max / energy_min)[mask]
+                amplitude * reference**2 * np.log(energy_max / energy_min)[mask]
             )
 
         return energy_flux
@@ -752,7 +786,7 @@ class PowerLawSpectralModel(SpectralModel):
         reference = self.reference.quantity
         amplitude = self.amplitude.quantity
         cov_index_ampl = self.covariance.data[0, 1] * amplitude.unit
-        return reference * np.exp(cov_index_ampl / (amplitude * index_err ** 2))
+        return reference * np.exp(cov_index_ampl / (amplitude * index_err**2))
 
 
 class PowerLawNormSpectralModel(SpectralModel):
@@ -773,7 +807,7 @@ class PowerLawNormSpectralModel(SpectralModel):
     """
 
     tag = ["PowerLawNormSpectralModel", "pl-norm"]
-    norm = Parameter("norm", 1, unit="", interp="log")
+    norm = Parameter("norm", 1, unit="", interp="log", is_norm=True)
     tilt = Parameter("tilt", 0, frozen=True)
     reference = Parameter("reference", "1 TeV", frozen=True)
 
@@ -804,7 +838,7 @@ class PowerLawNormSpectralModel(SpectralModel):
         """Evaluate the energy flux (static function)"""
         val = -1 * tilt + 2
 
-        prefactor = norm * reference ** 2 / val
+        prefactor = norm * reference**2 / val
         upper = (energy_max / reference) ** val
         lower = (energy_min / reference) ** val
         energy_flux = prefactor * (upper - lower)
@@ -815,7 +849,7 @@ class PowerLawNormSpectralModel(SpectralModel):
             # see https://www.wolframalpha.com/input/?i=a+*+x+*+(x%2Fb)+%5E+(-2)
             # for reference
             energy_flux[mask] = (
-                norm * reference ** 2 * np.log(energy_max / energy_min)[mask]
+                norm * reference**2 * np.log(energy_max / energy_min)[mask]
             )
 
         return energy_flux
@@ -845,7 +879,7 @@ class PowerLawNormSpectralModel(SpectralModel):
         reference = self.reference.quantity
         norm = self.norm.quantity
         cov_tilt_norm = self.covariance.data[0, 1] * norm.unit
-        return reference * np.exp(cov_tilt_norm / (norm * tilt_err ** 2))
+        return reference * np.exp(cov_tilt_norm / (norm * tilt_err**2))
 
 
 class PowerLaw2SpectralModel(SpectralModel):
@@ -871,7 +905,11 @@ class PowerLaw2SpectralModel(SpectralModel):
     tag = ["PowerLaw2SpectralModel", "pl-2"]
 
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1", scale_method="scale10", interp="log"
+        name="amplitude",
+        value="1e-12 cm-2 s-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     index = Parameter("index", 2)
     emin = Parameter("emin", "0.1 TeV", frozen=True)
@@ -955,7 +993,11 @@ class BrokenPowerLawSpectralModel(SpectralModel):
     index1 = Parameter("index1", 2.0)
     index2 = Parameter("index2", 2.0)
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1 TeV-1", scale_method="scale10", interp="log"
+        name="amplitude",
+        value="1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     ebreak = Parameter("ebreak", "1 TeV")
 
@@ -999,7 +1041,11 @@ class SmoothBrokenPowerLawSpectralModel(SpectralModel):
     index1 = Parameter("index1", 2.0)
     index2 = Parameter("index2", 2.0)
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1 TeV-1", scale_method="scale10", interp="log"
+        name="amplitude",
+        value="1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     ebreak = Parameter("ebreak", "1 TeV")
     reference = Parameter("reference", "1 TeV", frozen=True)
@@ -1124,7 +1170,11 @@ class ExpCutoffPowerLawSpectralModel(SpectralModel):
 
     index = Parameter("index", 1.5)
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1 TeV-1", scale_method="scale10", interp="log"
+        name="amplitude",
+        value="1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     reference = Parameter("reference", "1 TeV", frozen=True)
     lambda_ = Parameter("lambda_", "0.1 TeV-1")
@@ -1181,7 +1231,7 @@ class ExpCutoffPowerLawNormSpectralModel(SpectralModel):
     tag = ["ExpCutoffPowerLawNormSpectralModel", "ecpl-norm"]
 
     index = Parameter("index", 1.5)
-    norm = Parameter("norm", 1, unit="", interp="log")
+    norm = Parameter("norm", 1, unit="", interp="log", is_norm=True)
     reference = Parameter("reference", "1 TeV", frozen=True)
     lambda_ = Parameter("lambda_", "0.1 TeV-1")
     alpha = Parameter("alpha", "1.0", frozen=True)
@@ -1215,7 +1265,11 @@ class ExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
     tag = ["ExpCutoffPowerLaw3FGLSpectralModel", "ecpl-3fgl"]
     index = Parameter("index", 1.5)
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1 TeV-1", scale_method="scale10", interp="log"
+        "amplitude",
+        "1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     reference = Parameter("reference", "1 TeV", frozen=True)
     ecut = Parameter("ecut", "10 TeV")
@@ -1255,7 +1309,11 @@ class SuperExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
 
     tag = ["SuperExpCutoffPowerLaw3FGLSpectralModel", "secpl-3fgl"]
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1 TeV-1", scale_method="scale10", interp="log"
+        "amplitude",
+        "1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     reference = Parameter("reference", "1 TeV", frozen=True)
     ecut = Parameter("ecut", "10 TeV")
@@ -1271,8 +1329,8 @@ class SuperExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
 
 
 class SuperExpCutoffPowerLaw4FGLSpectralModel(SpectralModel):
-    r"""Spectral super exponential cutoff power-law model used for 4FGL.
-
+    r"""Spectral super exponential cutoff power-law model used for 4FGL-DR1 (and DR2).
+    See equation (4) of https://arxiv.org/pdf/1902.10045.pdf
     For more information see :ref:`super-exp-cutoff-powerlaw-4fgl-spectral-model`.
 
     Parameters
@@ -1287,12 +1345,16 @@ class SuperExpCutoffPowerLaw4FGLSpectralModel(SpectralModel):
         :math:`E_0`
     expfactor : `~astropy.units.Quantity`
         :math:`a`, given as dimensionless value but
-        internally assumes unit of :math:`[E_0]` power :math:`-\Gamma_2`
+        internally assumes unit of :math: `[E_0]` power :math:`-\Gamma_2`
     """
 
     tag = ["SuperExpCutoffPowerLaw4FGLSpectralModel", "secpl-4fgl"]
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1 TeV-1", scale_method="scale10", interp="log"
+        "amplitude",
+        "1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     reference = Parameter("reference", "1 TeV", frozen=True)
     expfactor = Parameter("expfactor", "1e-2")
@@ -1305,12 +1367,62 @@ class SuperExpCutoffPowerLaw4FGLSpectralModel(SpectralModel):
         pwl = amplitude * (energy / reference) ** (-index_1)
         cutoff = np.exp(
             expfactor
-            / reference.unit ** index_2
-            * (reference ** index_2 - energy ** index_2)
+            / reference.unit**index_2
+            * (reference**index_2 - energy**index_2)
         )
         return pwl * cutoff
 
 
+class SuperExpCutoffPowerLaw4FGLDR3SpectralModel(SpectralModel):
+    r"""Spectral super exponential cutoff power-law model used for 4FGL-DR3.
+    See equations (2) and (3) of https://arxiv.org/pdf/2201.11184.pdf
+    For more information see :ref:`super-exp-cutoff-powerlaw-4fgl-dr3-spectral-model`.
+
+    Parameters
+    ----------
+    index_1 : `~astropy.units.Quantity`
+        :math:`\Gamma_1`
+    index_2 : `~astropy.units.Quantity`
+        :math:`\Gamma_2`
+    amplitude : `~astropy.units.Quantity`
+        :math:`\phi_0`
+    reference : `~astropy.units.Quantity`
+        :math:`E_0`
+    expfactor : `~astropy.units.Quantity`
+        :math:`a`, given as dimensionless value
+    """
+
+    tag = ["SuperExpCutoffPowerLaw4FGLDR3SpectralModel", "secpl-4fgl-dr3"]
+    amplitude = Parameter(
+        name="amplitude",
+        value="1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
+    )
+    reference = Parameter("reference", "1 TeV", frozen=True)
+    expfactor = Parameter("expfactor", "1e-2")
+    index_1 = Parameter("index_1", 1.5)
+    index_2 = Parameter("index_2", 2)
+
+    @staticmethod
+    def evaluate(energy, amplitude, reference, expfactor, index_1, index_2):
+        """Evaluate the model (static function)."""
+        # https://fermi.gsfc.nasa.gov/ssc/data/analysis/scitools/source_models.html#PLSuperExpCutoff4
+        pwl = amplitude * (energy / reference) ** (-index_1)
+        cutoff = (energy / reference) ** (expfactor / index_2) * np.exp(
+            expfactor / index_2**2 * (1 - (energy / reference) ** index_2)
+        )
+
+        mask = np.abs(index_2 * np.log(energy / reference)) < 1e-2
+        ln_ = np.log(energy[mask] / reference)
+        power = expfactor * (
+            ln_ / 2.0 + index_2 / 6.0 * ln_**2.0 + index_2**2.0 / 24.0 * ln_**3
+        )
+        cutoff[mask] = (energy[mask] / reference) ** power
+        return pwl * cutoff
+
+
 class LogParabolaSpectralModel(SpectralModel):
     r"""Spectral log parabola model.
 
@@ -1334,7 +1446,11 @@ class LogParabolaSpectralModel(SpectralModel):
     """
     tag = ["LogParabolaSpectralModel", "lp"]
     amplitude = Parameter(
-        "amplitude", "1e-12 cm-2 s-1 TeV-1", scale_method="scale10", interp="log"
+        "amplitude",
+        "1e-12 cm-2 s-1 TeV-1",
+        scale_method="scale10",
+        interp="log",
+        is_norm=True,
     )
     reference = Parameter("reference", "10 TeV", frozen=True)
     alpha = Parameter("alpha", 2)
@@ -1387,7 +1503,7 @@ class LogParabolaNormSpectralModel(SpectralModel):
     LogParabolaSpectralModel
     """
     tag = ["LogParabolaNormSpectralModel", "lp-norm"]
-    norm = Parameter("norm", 1, unit="", interp="log")
+    norm = Parameter("norm", 1, unit="", interp="log", is_norm=True)
     reference = Parameter("reference", "10 TeV", frozen=True)
     alpha = Parameter("alpha", 2)
     beta = Parameter("beta", 1)
@@ -1427,6 +1543,7 @@ class TemplateSpectralModel(SpectralModel):
         Meta information, meta['filename'] will be used for serialization
     """
 
+    norm = Parameter("norm", 1, unit="", interp="log", is_norm=True, frozen=True)
     tag = ["TemplateSpectralModel", "template"]
 
     def __init__(
@@ -1443,6 +1560,9 @@ class TemplateSpectralModel(SpectralModel):
         interp_kwargs.setdefault("values_scale", "log")
         interp_kwargs.setdefault("points_scale", ("log",))
 
+        if len(energy) == 1:
+            interp_kwargs["method"] = "nearest"
+
         self._evaluate = ScaledRegularGridInterpolator(
             points=(energy,), values=values, **interp_kwargs
         )
@@ -1499,9 +1619,9 @@ class TemplateSpectralModel(SpectralModel):
         kwargs.setdefault("interp_kwargs", {"values_scale": "lin"})
         return cls(energy=energy, values=values, **kwargs)
 
-    def evaluate(self, energy):
+    def evaluate(self, energy, norm):
         """Evaluate the model (static function)."""
-        return self._evaluate((energy,), clip=True)
+        return norm * self._evaluate((energy,), clip=True)
 
     def to_dict(self, full_output=False):
         return {
@@ -1533,6 +1653,104 @@ class TemplateSpectralModel(SpectralModel):
         return cls(energy=energy, values=values, **kwargs)
 
 
+class TemplateNDSpectralModel(SpectralModel):
+    """A model generated from a ND map where extra dimensions define the parameter space.
+
+    Parameters
+    ----------
+    map : `~gammapy.maps.RegionNDMap`
+        Map template.
+    meta : dict, optional
+        Meta information, meta['filename'] will be used for serialization
+    interp_kwargs : dict
+        Interpolation keyword arguments passed to `gammapy.maps.Map.interp_by_pix`.
+        Default arguments are {'method': 'linear', 'fill_value': 0}.
+    """
+
+    tag = ["TemplateNDSpectralModel", "templateND"]
+
+    def __init__(self, map, interp_kwargs=None, meta=None, filename=None):
+        self._map = map.copy()
+        self.meta = dict() if meta is None else meta
+        if filename is not None:
+            filename = str(make_path(filename))
+        self.filename = filename
+
+        points_scale = [
+            "lin",
+            "lin",
+            "log",
+        ]
+        parameters = []
+        has_energy = False
+        for axis in map.geom.axes:
+            if axis.name not in ["energy_true", "energy"]:
+                center = (axis.bounds[1] + axis.bounds[0]) / 2
+                parameter = Parameter(
+                    name=axis.name,
+                    value=center,
+                    unit=axis.unit,
+                    scale_method="scale10",
+                    min=axis.bounds[0],
+                    max=axis.bounds[-1],
+                    interp=axis.interp,
+                )
+                points_scale.append(axis.interp)
+                parameters.append(parameter)
+            else:
+                has_energy |= True
+        if not has_energy:
+            raise ValueError("Invalid map, no energy axis found")
+
+        self.default_parameters = Parameters(parameters)
+
+        interp_kwargs = interp_kwargs or {}
+        interp_kwargs.setdefault("values_scale", "log")
+        interp_kwargs.setdefault("points_scale", points_scale)
+        self._interp_kwargs = interp_kwargs
+        super().__init__()
+
+    @property
+    def map(self):
+        """Template map  (`~gammapy.maps.RegionNDMap`)"""
+        return self._map
+
+    def evaluate(self, energy, **kwargs):
+        coord = {"energy_true": energy}
+        coord.update(kwargs)
+
+        pixels = [0, 0] + [
+            self.map.geom.axes[key].coord_to_pix(value) for key, value in coord.items()
+        ]
+
+        val = self.map.interp_by_pix(pixels, **self._interp_kwargs)
+        return u.Quantity(val, self.map.unit, copy=False)
+
+    def write(self, overwrite=False):
+        if self.filename is None:
+            raise IOError("Missing filename")
+        elif os.path.isfile(self.filename) and not overwrite:
+            log.warning("Template file already exits, and overwrite is False")
+        else:
+            self.map.write(self.filename)
+
+    @classmethod
+    def from_dict(cls, data):
+        filename = data["filename"]
+        m = RegionNDMap.read(filename)
+        model = cls(m, filename=filename)
+        for idx, p in enumerate(model.parameters):
+            p.value = data["spectral"]["parameters"][idx]["value"]
+        return model
+
+    def to_dict(self, full_output=False):
+        """Create dict for YAML serilisation"""
+        data = super().to_dict(full_output)
+        data["filename"] = self.filename
+        data["unit"] = str(self.map.unit)
+        return data
+
+
 class ScaleSpectralModel(SpectralModel):
     """Wrapper to scale another spectral model by a norm factor.
 
@@ -1545,7 +1763,7 @@ class ScaleSpectralModel(SpectralModel):
     """
 
     tag = ["ScaleSpectralModel", "scale"]
-    norm = Parameter("norm", 1, unit="", interp="log")
+    norm = Parameter("norm", 1, unit="", interp="log", is_norm=True)
 
     def __init__(self, model, norm=norm.quantity):
         self.model = model
@@ -1766,7 +1984,6 @@ class NaimaSpectralModel(SpectralModel):
         import naima
 
         self.radiative_model = radiative_model
-        self._particle_distribution = self.radiative_model.particle_distribution
         self.distance = u.Quantity(distance)
         self.seed = seed
 
@@ -1775,16 +1992,17 @@ class NaimaSpectralModel(SpectralModel):
 
         self.nested_models = nested_models
 
-        if isinstance(self._particle_distribution, naima.models.TableModel):
+        if isinstance(self.particle_distribution, naima.models.TableModel):
             param_names = ["amplitude"]
         else:
-            param_names = self._particle_distribution.param_names
+            param_names = self.particle_distribution.param_names
 
         parameters = []
 
         for name in param_names:
-            value = getattr(self._particle_distribution, name)
-            parameter = Parameter(name, value)
+            value = getattr(self.particle_distribution, name)
+            is_norm = name == "amplitude"
+            parameter = Parameter(name, value, is_norm=is_norm)
             parameters.append(parameter)
 
         # In case of a synchrotron radiative model, append B to the fittable parameters
@@ -1794,21 +2012,42 @@ class NaimaSpectralModel(SpectralModel):
             parameters.append(parameter)
 
         # In case of a synchrotron self compton model, append B and Rpwn to the fittable parameters
-        if (
-            isinstance(self.radiative_model, naima.models.InverseCompton)
-            and "SSC" in self.nested_models
-        ):
+        if self.include_ssc:
             B = self.nested_models["SSC"]["B"]
             radius = self.nested_models["SSC"]["radius"]
             parameters.append(Parameter("B", B))
             parameters.append(Parameter("radius", radius, frozen=True))
 
-        for p in parameters:
-            p.scale_method = "scale10"
-
         self.default_parameters = Parameters(parameters)
+        self.ssc_energy = np.logspace(-7, 9, 100) * u.eV
         super().__init__()
 
+    @property
+    def include_ssc(self):
+        """Whether the model includes an SSC component"""
+        import naima
+
+        is_ic_model = isinstance(self.radiative_model, naima.models.InverseCompton)
+        return is_ic_model and "SSC" in self.nested_models
+
+    @property
+    def ssc_model(self):
+        """Synchrotron model"""
+        import naima
+
+        if self.include_ssc:
+            return naima.models.Synchrotron(
+                self.particle_distribution,
+                B=self.B.quantity,
+                Eemax=self.radiative_model.Eemax,
+                Eemin=self.radiative_model.Eemin,
+            )
+
+    @property
+    def particle_distribution(self):
+        """Particle distribution"""
+        return self.radiative_model.particle_distribution
+
     def _evaluate_ssc(
         self,
         energy,
@@ -1822,18 +2061,10 @@ class NaimaSpectralModel(SpectralModel):
         "https://naima.readthedocs.io/en/latest/examples.html#crab-nebula-ssc-model"
 
         """
-        import naima
-
-        SYN = naima.models.Synchrotron(
-            self._particle_distribution,
-            B=self.B.quantity,
-            Eemax=self.radiative_model.Eemax,
-            Eemin=self.radiative_model.Eemin,
-        )
-
-        Esy = np.logspace(-7, 9, 100) * u.eV
-        Lsy = SYN.flux(Esy, distance=0 * u.cm)  # use distance 0 to get luminosity
-        phn_sy = Lsy / (4 * np.pi * self.radius.quantity ** 2 * const.c) * 2.24
+        Lsy = self.ssc_model.flux(
+            self.ssc_energy, distance=0 * u.cm
+        )  # use distance 0 to get luminosity
+        phn_sy = Lsy / (4 * np.pi * self.radius.quantity**2 * const.c) * 2.24
         # The factor 2.24 comes from the assumption on uniform synchrotron
         # emissivity inside a sphere
 
@@ -1841,7 +2072,7 @@ class NaimaSpectralModel(SpectralModel):
             self.radiative_model.seed_photon_fields["SSC"] = {
                 "isotropic": True,
                 "type": "array",
-                "energy": Esy,
+                "energy": self.ssc_energy,
                 "photon_density": phn_sy,
             }
         else:
@@ -1849,23 +2080,33 @@ class NaimaSpectralModel(SpectralModel):
 
         dnde = self.radiative_model.flux(
             energy, seed=self.seed, distance=self.distance
-        ) + SYN.flux(energy, distance=self.distance)
+        ) + self.ssc_model.flux(energy, distance=self.distance)
         return dnde
 
-    def evaluate(self, energy, **kwargs):
-        """Evaluate the model."""
-        import naima
-
+    def _update_naima_parameters(self, **kwargs):
+        """Update Naima model parameters"""
         for name, value in kwargs.items():
-            setattr(self._particle_distribution, name, value)
+            setattr(self.particle_distribution, name, value)
 
         if "B" in self.radiative_model.param_names:
             self.radiative_model.B = self.B.quantity
 
-        if (
-            isinstance(self.radiative_model, naima.models.InverseCompton)
-            and "SSC" in self.nested_models
-        ):
+    def evaluate(self, energy, **kwargs):
+        """Evaluate the model.
+
+        Parameters
+        ----------
+        energy : `~astropy.units.Quantity`
+            Energy to evaluate the model at.
+
+        Returns
+        -------
+        dnde : `~astropy.units.Quantity`
+            Differential flux at given energy.
+        """
+        self._update_naima_parameters(**kwargs)
+
+        if self.include_ssc:
             dnde = self._evaluate_ssc(energy.flatten())
         elif self.seed is not None:
             dnde = self.radiative_model.flux(
@@ -1875,7 +2116,7 @@ class NaimaSpectralModel(SpectralModel):
             dnde = self.radiative_model.flux(energy.flatten(), distance=self.distance)
 
         dnde = dnde.reshape(energy.shape)
-        unit = 1 / (energy.unit * u.cm ** 2 * u.s)
+        unit = 1 / (energy.unit * u.cm**2 * u.s)
         return dnde.to(unit)
 
     def to_dict(self, full_output=True):
@@ -1902,7 +2143,7 @@ class GaussianSpectralModel(SpectralModel):
 
     Parameters
     ----------
-    norm : `~astropy.units.Quantity`
+    amplitude : `~astropy.units.Quantity`
         :math:`N_0`
     mean : `~astropy.units.Quantity`
         :math:`\bar{E}`
@@ -1911,16 +2152,18 @@ class GaussianSpectralModel(SpectralModel):
     """
 
     tag = ["GaussianSpectralModel", "gauss"]
-    norm = Parameter("norm", 1e-12 * u.Unit("cm-2 s-1"), interp="log")
+    amplitude = Parameter(
+        "amplitude", 1e-12 * u.Unit("cm-2 s-1"), interp="log", is_norm=True
+    )
     mean = Parameter("mean", 1 * u.TeV)
     sigma = Parameter("sigma", 2 * u.TeV)
 
     @staticmethod
-    def evaluate(energy, norm, mean, sigma):
+    def evaluate(energy, amplitude, mean, sigma):
         return (
-            norm
+            amplitude
             / (sigma * np.sqrt(2 * np.pi))
-            * np.exp(-((energy - mean) ** 2) / (2 * sigma ** 2))
+            * np.exp(-((energy - mean) ** 2) / (2 * sigma**2))
         )
 
     def integral(self, energy_min, energy_max, **kwargs):
@@ -1944,7 +2187,7 @@ class GaussianSpectralModel(SpectralModel):
         ).to_value("")
 
         return (
-            self.norm.quantity
+            self.amplitude.quantity
             / 2
             * (scipy.special.erf(u_max) - scipy.special.erf(u_min))
         )
@@ -1969,8 +2212,8 @@ class GaussianSpectralModel(SpectralModel):
         u_max = (
             (energy_max - self.mean.quantity) / (np.sqrt(2) * self.sigma.quantity)
         ).to_value("")
-        a = self.norm.quantity * self.sigma.quantity / np.sqrt(2 * np.pi)
-        b = self.norm.quantity * self.mean.quantity / 2
-        return a * (np.exp(-(u_min ** 2)) - np.exp(-(u_max ** 2))) + b * (
+        a = self.amplitude.quantity * self.sigma.quantity / np.sqrt(2 * np.pi)
+        b = self.amplitude.quantity * self.mean.quantity / 2
+        return a * (np.exp(-(u_min**2)) - np.exp(-(u_max**2))) + b * (
             scipy.special.erf(u_max) - scipy.special.erf(u_min)
         )
