@@ -8,8 +8,6 @@ from gammapy.modeling import Fit, Parameter
 from gammapy.modeling.models import ModelBase, Models
 from gammapy.utils.testing import requires_dependency
 
-pytest.importorskip("iminuit")
-
 
 class MyModel(ModelBase):
     x = Parameter("x", 2)
@@ -35,12 +33,12 @@ class MyDataset(Dataset):
 
     def stat_sum(self):
         # self._model.parameters = parameters
-        x, y, z = [p.value for p in self.models.parameters]
+        x, y, z = [p.value for p in self.models.parameters.unique_parameters]
         x_opt, y_opt, z_opt = 2, 3e2, 4e-2
         return (x - x_opt) ** 2 + (y - y_opt) ** 2 + (z - z_opt) ** 2
 
     def fcn(self):
-        x, y, z = [p.value for p in self.models.parameters]
+        x, y, z = [p.value for p in self.models.parameters.unique_parameters]
         x_opt, y_opt, z_opt = 2, 3e5, 4e-5
         x_err, y_err, z_err = 0.2, 3e4, 4e-6
         return (
@@ -53,7 +51,6 @@ class MyDataset(Dataset):
         """Statistic array, one value per data point."""
 
 
-@requires_dependency("iminuit")
 @requires_dependency("sherpa")
 @pytest.mark.parametrize("backend", ["sherpa", "scipy"])
 def test_optimize_backend_and_covariance(backend):
@@ -95,6 +92,8 @@ def test_run(backend):
 
     assert result.success
     assert result.optimize_result.method == "migrad"
+    assert result.covariance_result.method == "hesse"
+    assert result.covariance_result.success
 
     assert_allclose(pars["x"].value, 2, rtol=1e-3)
     assert_allclose(pars["y"].value, 3e2, rtol=1e-3)
@@ -109,6 +108,43 @@ def test_run(backend):
     assert_allclose(correlation[0, 2], 0, atol=1e-7)
     assert_allclose(correlation[1, 2], 0, atol=1e-7)
 
+    # Verify that the fit result models are independent of the dataset ones
+    pars["x"].value = 3
+    assert_allclose(result.parameters["x"].value, 2, rtol=1e-3)
+
+    # check parameters from the result object
+    pars = result.parameters
+    assert_allclose(pars["x"].error, 1, rtol=1e-7)
+    assert_allclose(pars["y"].error, 1, rtol=1e-7)
+    assert_allclose(pars["z"].error, 1, rtol=1e-7)
+
+
+@pytest.mark.parametrize("backend", ["minuit"])
+def test_run_linked(backend):
+    dataset = MyDataset()
+    model1 = MyModel(x=1.99, y=2.99e3, z=3.99e-2)
+    model1.name = "model1"
+    model2 = MyModel(x=0.99, y=0.99e3, z=3.99e-2)
+    model2.name = "model2"
+    model2.x = model1.x
+    model2.y = model1.y
+    model2.z = model1.z
+
+    dataset._models = Models([model1, model2])
+
+    fit = Fit(backend=backend)
+    fit.run([dataset])
+
+    assert len(dataset.models.parameters.unique_parameters) == 3
+    assert dataset.models.covariance.shape == (6, 6)
+    expected = [
+        [1.00000000e00, 1.69728073e-30, 4.76456033e-16],
+        [1.69728073e-30, 1.00000000e00, 3.56230294e-15],
+        [4.76456033e-16, 3.56230294e-15, 1.00000000e00],
+    ]
+    assert_allclose(dataset.models[0].covariance.data, expected)
+    assert_allclose(dataset.models[1].covariance.data, expected)
+
 
 @requires_dependency("sherpa")
 @pytest.mark.parametrize("backend", ["minuit", "sherpa", "scipy"])
