@@ -17,16 +17,14 @@ Here's some good resources with working examples:
 - https://github.com/bokeh/bokeh/tree/master/bokeh/sphinxext
 """
 import os
-from distutils.util import strtobool
+from configparser import ConfigParser
 from pathlib import Path
-import nbformat
+from docutils.parsers.rst import Directive
 from docutils.parsers.rst.directives import register_directive
 from docutils.parsers.rst.directives.body import CodeBlock
 from docutils.parsers.rst.directives.images import Image
-from docutils.parsers.rst.directives.misc import Include
-from nbformat.v4 import new_markdown_cell
+from docutils.parsers.rst.directives.misc import Include, Raw
 from sphinx.util import logging
-from gammapy import __version__
 from gammapy.analysis import AnalysisConfig
 
 try:
@@ -36,6 +34,86 @@ except KeyError:
     HAS_GP_DATA = False
 
 log = logging.getLogger(__name__)
+PATH_CFG = Path(__file__).resolve().parent / ".." / ".."
+
+# fetch params from setup.cfg
+conf = ConfigParser()
+conf.read(PATH_CFG / "setup.cfg")
+build_docs_cfg = dict(conf.items("build_docs"))
+PATH_NBS = build_docs_cfg["downloadable-notebooks"]
+
+
+class AccordionHeader(Directive):
+    """
+    Inserts HTML code to open an accordion box in the How To.
+    """
+
+    option_spec = {"id": str, "title": str, "link": str}
+
+    def run(self):
+        raw = f"""
+            <div id="accordion" class="shadow tutorial-accordion">
+        <div class="card tutorial-card">
+            <div class="card-header collapsed card-link" data-toggle="collapse" data-target="#{self.options["id"]}">
+                <div class="d-flex flex-row tutorial-card-header-1">
+                    <div class="d-flex flex-row tutorial-card-header-2">
+                        <button class="btn btn-dark btn-sm"></button>
+                        {self.options["title"]}
+                    </div>
+        """
+        if self.options.get("link", None):
+            raw += f"""
+             <span class="badge gs-badge-link">
+             <a class="reference external" href="{self.options["link"]}">Straight to tutorial…</a>
+             </span>
+             """
+        raw += f"""    
+
+                </div>
+            </div>
+            <div id="{self.options["id"]}" class="collapse" data-parent="#accordion">
+                <div class="card-body">
+        """
+        include_lines = raw.splitlines()
+        c = Raw(
+            self.name,
+            ["html"],
+            self.options,
+            include_lines,  # content
+            self.lineno,
+            self.content_offset,
+            self.block_text,
+            self.state,
+            self.state_machine,
+        )
+        return c.run()
+
+
+class AccordionFooter(Directive):
+    """
+    Inserts HTML code to close an accordion box in the How To.
+    """
+
+    def run(self):
+        raw = """
+                    </div>
+                </div>
+            </div>
+        </div>        
+        """
+        include_lines = raw.splitlines()
+        c = Raw(
+            self.name,
+            ["html"],
+            self.options,
+            include_lines,  # content
+            self.lineno,
+            self.content_offset,
+            self.block_text,
+            self.state,
+            self.state_machine,
+        )
+        return c.run()
 
 
 class HowtoHLI(Include):
@@ -46,7 +124,7 @@ class HowtoHLI(Include):
         section = self.arguments[0]
         doc = AnalysisConfig._get_doc_sections()
         for keyword in doc.keys():
-            if section == "" or section == keyword:
+            if section in ["", keyword]:
                 raw += doc[keyword]
         include_lines = raw.splitlines()
         codeblock = CodeBlock(
@@ -102,75 +180,5 @@ def gammapy_sphinx_ext_activate():
     # Register our directives and roles with Sphinx
     register_directive("gp-image", DocsImage)
     register_directive("gp-howto-hli", HowtoHLI)
-
-
-def parse_notebooks(folder, url_docs):
-    """Parse Jupyter notebook.
-
-    Modifies raw and html-fixed notebooks so they will not have broken links
-    to other files in the documentation. Adds a box to the sphinx formatted
-    notebooks with info and links to the *.ipynb and *.py files.
-    """
-    release_number_binder = __version__
-    if "dev" in __version__:
-        release_number_binder = "master"
-
-    DOWNLOAD_CELL = """
-<div class="alert alert-info">
-
-**This is a fixed-text formatted version of a Jupyter notebook**
-
-- Try online [![Binder](https://static.mybinder.org/badge.svg)](https://mybinder.org/v2/gh/gammapy/gammapy-webpage/v{release_number_binder}?urlpath=lab/tree/{nb_filename})
-- You can contribute with your own notebooks in this
-[GitHub repository](https://github.com/gammapy/gammapy/tree/master/tutorials).
-- **Source files:**
-[{nb_filename}](../_static/notebooks/{nb_filename}) |
-[{py_filename}](../_static/notebooks/{py_filename})
-</div>
-"""
-
-    for nbpath in list(folder.glob("*.ipynb")):
-        if str(folder) == "notebooks":
-
-            # add binder cell
-            nb_filename = str(nbpath).replace("notebooks/", "")
-            py_filename = nb_filename.replace("ipynb", "py")
-            ctx = dict(
-                nb_filename=nb_filename,
-                py_filename=py_filename,
-                release_number_binder=release_number_binder,
-            )
-            strcell = DOWNLOAD_CELL.format(**ctx)
-            rawnb = nbformat.read(str(nbpath), as_version=nbformat.NO_CONVERT)
-
-            if "nbsphinx" not in rawnb.metadata:
-                rawnb.metadata["nbsphinx"] = {"orphan": bool("true")}
-                rawnb.cells.insert(0, new_markdown_cell(strcell))
-
-                # add latex format
-                for cell in rawnb.cells:
-                    if "outputs" in cell.keys():
-                        for output in cell["outputs"]:
-                            if output["output_type"] == "execute_result":
-                                if "text/latex" in output["data"].keys():
-                                    output["data"]["text/latex"] = output["data"][
-                                        "text/latex"
-                                    ].replace("$", "$$")
-                nbformat.write(rawnb, str(nbpath))
-
-
-def gammapy_sphinx_notebooks(setup_cfg):
-    """Manage creation of Sphinx-formatted notebooks."""
-    if not strtobool(setup_cfg["build_notebooks"]):
-        log.info("Config build_notebooks is False; skipping notebook processing")
-        return
-
-    url_docs = setup_cfg["url_docs"]
-
-    # fix links
-    filled_notebooks_folder = Path("notebooks")
-    download_notebooks_folder = Path("_static") / "notebooks"
-
-    if filled_notebooks_folder.is_dir():
-        parse_notebooks(filled_notebooks_folder, url_docs)
-        parse_notebooks(download_notebooks_folder, url_docs)
+    register_directive("accordion-header", AccordionHeader)
+    register_directive("accordion-footer", AccordionFooter)
