@@ -1,9 +1,13 @@
 import numpy as np
+import matplotlib.pyplot as plt
 
 # taken from the matploltlib documentation
 # https://matplotlib.org/3.1.0/gallery/images_contours_and_fields/image_annotated_heatmap.html#sphx-glr-gallery-images-contours-and-fields-image-annotated-heatmap-py
 
-__all__ = ["plot_heatmap", "annotate_heatmap"]
+__all__ = [
+    "annotate_heatmap",
+    "plot_heatmap",
+]
 
 
 def plot_heatmap(
@@ -30,8 +34,6 @@ def plot_heatmap(
     **kwargs
         All other arguments are forwarded to `imshow`.
     """
-    import matplotlib.pyplot as plt
-
     if ax is None:
         ax = plt.gca()
 
