@@ -1,10 +1,12 @@
 import numpy as np
+from scipy.interpolate import CubicSpline
+import matplotlib.pyplot as plt
 from gammapy.maps import MapAxis
 from gammapy.maps.utils import edges_from_lo_hi
 
 __all__ = [
-    "plot_spectrum_datasets_off_regions",
     "plot_contour_line",
+    "plot_spectrum_datasets_off_regions",
     "plot_theta_squared_table",
 ]
 
@@ -61,11 +63,12 @@ def plot_spectrum_datasets_off_regions(
         plot_spectrum_datasets_off_regions(datasets2, ax, legend=True, legend_kwargs=dict(ncol=2))
         plot_spectrum_datasets_off_regions(datasets3, ax, legend=False, edgecolor='magenta')
     """
-    import matplotlib.pyplot as plt
     from matplotlib.legend_handler import HandlerPatch, HandlerTuple
     from matplotlib.patches import CirclePolygon, Patch
 
-    ax = ax or plt.gca(projection=datasets[0].counts_off.geom.wcs)
+    if ax is None:
+        ax = plt.subplot(projection=datasets[0].counts_off.geom.wcs)
+
     legend = legend or legend is None and len(datasets) <= 10
     legend_kwargs = legend_kwargs or {}
     handles, labels = [], []
@@ -111,8 +114,6 @@ def plot_spectrum_datasets_off_regions(
 
 def plot_contour_line(ax, x, y, **kwargs):
     """Plot smooth curve from contour points"""
-    from scipy.interpolate import CubicSpline
-
     # close contour
     xf = np.append(x, x[0])
     yf = np.append(y, y[0])
@@ -153,8 +154,6 @@ def plot_theta_squared_table(table):
     table : `~astropy.table.Table`
         Required columns: theta2_min, theta2_max, counts, counts_off and alpha
     """
-    import matplotlib.pyplot as plt
-
     theta2_edges = edges_from_lo_hi(
         table["theta2_min"].quantity, table["theta2_max"].quantity
     )
